@@ -26,6 +26,7 @@
 #include <assert.h>
 #include <gnome.h>
 
+#include "aboutbox.h"
 #include "frontend.h"
 #include "cards.h"
 #include "cost.h"
@@ -49,17 +50,17 @@ enum {
 	MAP_PAGE,		/* the map */
 	TRADE_PAGE,		/* trading interface */
 	QUOTE_PAGE,		/* submit quotes page */
-	LEGEND_PAGE,	/* legend */
+	LEGEND_PAGE,		/* legend */
 	SPLASH_PAGE		/* splash screen */
 };
 
-static GtkWidget *map_notebook; /* map area panel */
+static GtkWidget *map_notebook;	/* map area panel */
 static GtkWidget *trade_page;	/* trade page in map area */
 static GtkWidget *quote_page;	/* quote page in map area */
 static GtkWidget *legend_page;	/* splash page in map area */
 static GtkWidget *splash_page;	/* splash page in map area */
 
-static GtkWidget *develop_notebook; /* development card area panel */
+static GtkWidget *develop_notebook;	/* development card area panel */
 
 static GtkWidget *messages_txt;	/* messages text widget */
 static GtkWidget *prompt_lbl;	/* big prompt messages */
@@ -68,66 +69,72 @@ static GtkWidget *app_bar;
 static GtkWidget *net_status;
 static GtkWidget *vp_target_status;
 
-static void preferences_cb(GtkWidget *widget, void *user_data);
-static void route_widget_event (GtkWidget *w, gpointer data);
+static void preferences_cb(GtkWidget * widget, void *user_data);
+static void route_widget_event(GtkWidget * w, gpointer data);
 
 static GnomeUIInfo game_menu[] = {
-	{ GNOME_APP_UI_ITEM, N_("_New game"), N_("Start a new game"),
-	  (gpointer)route_widget_event, (gpointer)GUI_CONNECT, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_NEW,
-	  'n', GDK_CONTROL_MASK, NULL },
-	{ GNOME_APP_UI_ITEM, N_("_Leave game"), N_("Leave this game"),
-	  (gpointer)route_widget_event, (gpointer)GUI_DISCONNECT, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_STOP,
-	  0, 0, NULL },
+	{GNOME_APP_UI_ITEM, N_("_New game"), N_("Start a new game"),
+	 (gpointer) route_widget_event, (gpointer) GUI_CONNECT, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GTK_STOCK_NEW,
+	 'n', GDK_CONTROL_MASK, NULL},
+	{GNOME_APP_UI_ITEM, N_("_Leave game"), N_("Leave this game"),
+	 (gpointer) route_widget_event, (gpointer) GUI_DISCONNECT, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GTK_STOCK_STOP,
+	 0, 0, NULL},
 #ifdef ADMIN_GTK
-	{ GNOME_APP_UI_ITEM, N_("_Admin"), N_("Administer Gnocatan server"),
-	  (gpointer)show_admin_interface, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_BLANK,
-	  'a', GDK_CONTROL_MASK, NULL },
-#endif /* ADMIN_GTK */
+	{GNOME_APP_UI_ITEM, N_("_Admin"), N_("Administer Gnocatan server"),
+	 (gpointer) show_admin_interface, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_BLANK,
+	 'a', GDK_CONTROL_MASK, NULL},
+#endif				/* ADMIN_GTK */
 	GNOMEUIINFO_SEPARATOR,
-	{ GNOME_APP_UI_ITEM, N_("_Player name"), N_("Change your player name"),
-	  (gpointer)route_widget_event, (gpointer)GUI_CHANGE_NAME, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_BLANK,
-	  'p', GDK_CONTROL_MASK, NULL },
+	{GNOME_APP_UI_ITEM, N_("_Player name"),
+	 N_("Change your player name"),
+	 (gpointer) route_widget_event, (gpointer) GUI_CHANGE_NAME, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_BLANK,
+	 'p', GDK_CONTROL_MASK, NULL},
 	GNOMEUIINFO_SEPARATOR,
-	{ GNOME_APP_UI_ITEM, N_("_Quit"), N_("Quit the program"),
-	  (gpointer)route_widget_event, (gpointer)GUI_QUIT, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_QUIT,
-	  'q', GDK_CONTROL_MASK, NULL },
+	{GNOME_APP_UI_ITEM, N_("_Quit"), N_("Quit the program"),
+	 (gpointer) route_widget_event, (gpointer) GUI_QUIT, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GTK_STOCK_QUIT,
+	 'q', GDK_CONTROL_MASK, NULL},
 
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo settings_menu[] = {
-	{ GNOME_APP_UI_ITEM, N_("Prefere_nces"), N_("Configure the application"),
-	  (gpointer)preferences_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GTK_STOCK_PREFERENCES, 0, 0, NULL },
+	{GNOME_APP_UI_ITEM, N_("Prefere_nces"),
+	 N_("Configure the application"),
+	 (gpointer) preferences_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	 GTK_STOCK_PREFERENCES, 0, 0, NULL},
 	GNOMEUIINFO_END
 };
 
-static void help_about_cb(GtkWidget *widget, void *user_data);
-static void help_legend_cb(GtkWidget *widget, void *user_data);
-static void help_histogram_cb(GtkWidget *widget, void *user_data);
-static void help_settings_cb(GtkWidget *widget, void *user_data);
+static void help_about_cb(GtkWidget * widget, void *user_data);
+static void help_legend_cb(GtkWidget * widget, void *user_data);
+static void help_histogram_cb(GtkWidget * widget, void *user_data);
+static void help_settings_cb(GtkWidget * widget, void *user_data);
 
 /* put this in non-const memory, because GNOMEUIINFO_HELP doesn't want a
  * const pointer. */
 static gchar app_name[] = "gnocatan";
 static GnomeUIInfo help_menu[] = {
-	{ GNOME_APP_UI_ITEM, N_("_Legend"), N_("Terrain legend and building costs"),
-	  (gpointer)help_legend_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GTK_STOCK_DIALOG_INFO, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("_Game Settings"), N_("Settings for the current game"),
-	  (gpointer)help_settings_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GTK_STOCK_DIALOG_INFO, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("_Dice Histogram"), N_("Histogram of dice rolls"),
-	  (gpointer)help_histogram_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GTK_STOCK_DIALOG_INFO, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("_About Gnocatan"), N_("Information about Gnocatan"),
-	  (gpointer)help_about_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GNOME_STOCK_ABOUT, 0, 0, NULL },
+	{GNOME_APP_UI_ITEM, N_("_Legend"),
+	 N_("Terrain legend and building costs"),
+	 (gpointer) help_legend_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	 GTK_STOCK_DIALOG_INFO, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("_Game Settings"),
+	 N_("Settings for the current game"),
+	 (gpointer) help_settings_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	 GTK_STOCK_DIALOG_INFO, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("_Dice Histogram"),
+	 N_("Histogram of dice rolls"),
+	 (gpointer) help_histogram_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	 GTK_STOCK_DIALOG_INFO, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("_About Gnocatan"),
+	 N_("Information about Gnocatan"),
+	 (gpointer) help_about_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	 GNOME_STOCK_ABOUT, 0, 0, NULL},
 
 	GNOMEUIINFO_SEPARATOR,
 
@@ -169,50 +176,51 @@ static const gchar *gnocatan_pixmaps[] = {
 };
 
 static GnomeUIInfo toolbar_uiinfo[] = {
-	{ GNOME_APP_UI_ITEM, N_("Roll Dice\n(F1)"), NULL,
-	  (gpointer)route_widget_event, (gpointer)GUI_ROLL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_DICE, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("Trade\n(F2)"), NULL,
-	  (gpointer)route_widget_event, (gpointer)GUI_TRADE, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_TRADE, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("Undo\n(F3)"), NULL,
-	  (gpointer)route_widget_event, (gpointer)GUI_UNDO, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_UNDO, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("Finish\n(F4)"), NULL,
-	  (gpointer)route_widget_event, (gpointer)GUI_FINISH, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_FINISH, 0, 0, NULL },
+	{GNOME_APP_UI_ITEM, N_("Roll Dice\n(F1)"), NULL,
+	 (gpointer) route_widget_event, (gpointer) GUI_ROLL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_DICE, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("Trade\n(F2)"), NULL,
+	 (gpointer) route_widget_event, (gpointer) GUI_TRADE, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_TRADE, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("Undo\n(F3)"), NULL,
+	 (gpointer) route_widget_event, (gpointer) GUI_UNDO, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GTK_STOCK_UNDO, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("Finish\n(F4)"), NULL,
+	 (gpointer) route_widget_event, (gpointer) GUI_FINISH, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_FINISH, 0, 0, NULL},
 
-	{ GNOME_APP_UI_ITEM, N_("Road\n(F5)"), NULL,
-	  (gpointer)route_widget_event, (gpointer)GUI_ROAD, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_ROAD, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("Ship\n(F6)"), NULL,
-	  (gpointer)route_widget_event, (gpointer)GUI_SHIP, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_SHIP, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("Move Ship\n(F7)"), NULL,
-	  (gpointer)route_widget_event, (gpointer)GUI_MOVE_SHIP, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_SHIP_MOVEMENT, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("Bridge\n(F8)"), NULL,
-	  (gpointer)route_widget_event, (gpointer)GUI_BRIDGE, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_BRIDGE, 0, 0, NULL },
+	{GNOME_APP_UI_ITEM, N_("Road\n(F5)"), NULL,
+	 (gpointer) route_widget_event, (gpointer) GUI_ROAD, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_ROAD, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("Ship\n(F6)"), NULL,
+	 (gpointer) route_widget_event, (gpointer) GUI_SHIP, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_SHIP, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("Move Ship\n(F7)"), NULL,
+	 (gpointer) route_widget_event, (gpointer) GUI_MOVE_SHIP, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_SHIP_MOVEMENT, 0, 0,
+	 NULL},
+	{GNOME_APP_UI_ITEM, N_("Bridge\n(F8)"), NULL,
+	 (gpointer) route_widget_event, (gpointer) GUI_BRIDGE, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_BRIDGE, 0, 0, NULL},
 
-	{ GNOME_APP_UI_ITEM, N_("Settlement\n(F9)"), NULL,
-	  (gpointer)route_widget_event, (gpointer)GUI_SETTLEMENT, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_SETTLEMENT, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("City\n(F10)"), NULL,
-	  (gpointer)route_widget_event, (gpointer)GUI_CITY, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_CITY, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("Develop\n(F11)"), NULL,
-	  (gpointer)route_widget_event, (gpointer)GUI_BUY_DEVELOP, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_DEVELOP, 0, 0, NULL },
+	{GNOME_APP_UI_ITEM, N_("Settlement\n(F9)"), NULL,
+	 (gpointer) route_widget_event, (gpointer) GUI_SETTLEMENT, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_SETTLEMENT, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("City\n(F10)"), NULL,
+	 (gpointer) route_widget_event, (gpointer) GUI_CITY, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_CITY, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("Develop\n(F11)"), NULL,
+	 (gpointer) route_widget_event, (gpointer) GUI_BUY_DEVELOP, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOCATAN_PIXMAP_DEVELOP, 0, 0, NULL},
 
-	  /* Only the first field matters.  Fill the whole struct with some
-	   * values anyway, to get rid of a compiler warning. */
-	{ GNOME_APP_UI_ENDOFINFO, NULL, NULL,
-	  NULL, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, NULL, 0, 0, NULL }
+	/* Only the first field matters.  Fill the whole struct with some
+	 * values anyway, to get rid of a compiler warning. */
+	{GNOME_APP_UI_ENDOFINFO, NULL, NULL,
+	 NULL, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, NULL, 0, 0, NULL}
 };
 
-GtkWidget *gui_get_dialog_button(GtkDialog *dlg, gint button)
+GtkWidget *gui_get_dialog_button(GtkDialog * dlg, gint button)
 {
 	GList *list;
 
@@ -227,22 +235,28 @@ GtkWidget *gui_get_dialog_button(GtkDialog *dlg, gint button)
 	return NULL;
 }
 
-void gui_set_instructions(const gchar *text)
+void gui_reset(void)
+{
+	guimap_reset(gmap);
+}
+
+void gui_set_instructions(const gchar * text)
 {
 	gnome_appbar_set_status(GNOME_APPBAR(app_bar), text);
 }
 
-void gui_set_vp_target_value( gint vp )
+void gui_set_vp_target_value(gint vp)
 {
 	gchar vp_text[30];
-	
+
 	/* Victory points target in statusbar */
-	g_snprintf( vp_text, sizeof(vp_text), _("Points Needed to Win: %i"), vp );
-	
-	gtk_label_set_text( GTK_LABEL(vp_target_status), vp_text );
+	g_snprintf(vp_text, sizeof(vp_text), _("Points Needed to Win: %i"),
+		   vp);
+
+	gtk_label_set_text(GTK_LABEL(vp_target_status), vp_text);
 }
 
-void gui_set_net_status(gchar *text)
+void gui_set_net_status(gchar * text)
 {
 	gtk_label_set_text(GTK_LABEL(net_status), text);
 }
@@ -251,30 +265,31 @@ void gui_cursor_none()
 {
 	MapElement dummyElement;
 	dummyElement.pointer = NULL;
-	guimap_cursor_set(gmap, NO_CURSOR, -1, NULL, NULL, &dummyElement, FALSE);
+	guimap_cursor_set(gmap, NO_CURSOR, -1, NULL, NULL, &dummyElement,
+			  FALSE);
 }
 
 void gui_cursor_set(CursorType type,
 		    CheckFunc check_func, SelectFunc select_func,
-		    const MapElement *user_data)
+		    const MapElement * user_data)
 {
 	guimap_cursor_set(gmap, type, my_player_num(),
 			  check_func, select_func, user_data, FALSE);
 }
 
-void gui_draw_hex(const Hex *hex)
+void gui_draw_hex(const Hex * hex)
 {
 	if (gmap->pixmap != NULL)
 		guimap_draw_hex(gmap, hex);
 }
 
-void gui_draw_edge(const Edge *edge)
+void gui_draw_edge(const Edge * edge)
 {
 	if (gmap->pixmap != NULL)
 		guimap_draw_edge(gmap, edge);
 }
 
-void gui_draw_node(const Node *node)
+void gui_draw_node(const Node * node)
 {
 	if (gmap->pixmap != NULL)
 		guimap_draw_node(gmap, node);
@@ -285,8 +300,8 @@ void gui_highlight_chits(gint roll)
 	guimap_highlight_chits(gmap, roll);
 }
 
-static gint expose_map_cb(GtkWidget *area, GdkEventExpose *event,
-		UNUSED(gpointer user_data))
+static gint expose_map_cb(GtkWidget * area, GdkEventExpose * event,
+			  UNUSED(gpointer user_data))
 {
 	if (area->window == NULL || gmap->map == NULL)
 		return FALSE;
@@ -294,22 +309,22 @@ static gint expose_map_cb(GtkWidget *area, GdkEventExpose *event,
 	if (gmap->pixmap == NULL) {
 		gmap->pixmap = gdk_pixmap_new(area->window,
 					      area->allocation.width,
-					      area->allocation.height,
-					      -1);
+					      area->allocation.height, -1);
 		guimap_display(gmap);
 	}
 
 	gdk_draw_drawable(area->window,
-			area->style->fg_gc[GTK_WIDGET_STATE(area)],
-			gmap->pixmap,
-			event->area.x, event->area.y,
-			event->area.x, event->area.y,
-			event->area.width, event->area.height);
+			  area->style->fg_gc[GTK_WIDGET_STATE(area)],
+			  gmap->pixmap,
+			  event->area.x, event->area.y,
+			  event->area.x, event->area.y,
+			  event->area.width, event->area.height);
 	return FALSE;
 }
 
-static gint configure_map_cb(GtkWidget *area, UNUSED(GdkEventConfigure *event),
-		UNUSED(gpointer user_data))
+static gint configure_map_cb(GtkWidget * area,
+			     UNUSED(GdkEventConfigure * event),
+			     UNUSED(gpointer user_data))
 {
 	if (area->window == NULL || gmap->map == NULL)
 		return FALSE;
@@ -326,8 +341,8 @@ static gint configure_map_cb(GtkWidget *area, UNUSED(GdkEventConfigure *event),
 	return FALSE;
 }
 
-static gint motion_notify_map_cb(GtkWidget *area, GdkEventMotion *event,
-		UNUSED(gpointer user_data))
+static gint motion_notify_map_cb(GtkWidget * area, GdkEventMotion * event,
+				 UNUSED(gpointer user_data))
 {
 	gint x;
 	gint y;
@@ -348,12 +363,12 @@ static gint motion_notify_map_cb(GtkWidget *area, GdkEventMotion *event,
 
 	dummyElement.pointer = NULL;
 	guimap_cursor_move(gmap, x, y, &dummyElement);
-  
+
 	return TRUE;
 }
 
-static gint button_press_map_cb(GtkWidget *area, GdkEventButton *event,
-		UNUSED(gpointer user_data))
+static gint button_press_map_cb(GtkWidget * area, GdkEventButton * event,
+				UNUSED(gpointer user_data))
 {
 	if (area->window == NULL || gmap->map == NULL
 	    || event->button != 1)
@@ -375,14 +390,14 @@ static GtkWidget *build_map_area(void)
 
 	gtk_widget_set_size_request(gmap->area, MAP_WIDTH, MAP_HEIGHT);
 	g_signal_connect(G_OBJECT(gmap->area), "expose_event",
-			G_CALLBACK(expose_map_cb), NULL);
-	g_signal_connect(G_OBJECT(gmap->area),"configure_event",
-			G_CALLBACK(configure_map_cb), NULL);
+			 G_CALLBACK(expose_map_cb), NULL);
+	g_signal_connect(G_OBJECT(gmap->area), "configure_event",
+			 G_CALLBACK(configure_map_cb), NULL);
 
 	g_signal_connect(G_OBJECT(gmap->area), "motion_notify_event",
-			G_CALLBACK(motion_notify_map_cb), NULL);
+			 G_CALLBACK(motion_notify_map_cb), NULL);
 	g_signal_connect(G_OBJECT(gmap->area), "button_press_event",
-			G_CALLBACK(button_press_map_cb), NULL);
+			 G_CALLBACK(button_press_map_cb), NULL);
 
 	gtk_widget_show(gmap->area);
 
@@ -416,7 +431,8 @@ static GtkWidget *build_messages_panel(void)
 	messages_txt = gtk_text_view_new();
 	gtk_widget_show(messages_txt);
 	gtk_container_add(GTK_CONTAINER(scroll_win), messages_txt);
-	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(messages_txt), GTK_WRAP_WORD);
+	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(messages_txt),
+				    GTK_WRAP_WORD);
 
 	message_window_set_text(messages_txt);
 
@@ -425,20 +441,22 @@ static GtkWidget *build_messages_panel(void)
 
 void gui_show_trade_page(gboolean show)
 {
-	chat_set_grab_focus_on_update(!show); /* Normal keyboard focus when visible */
+	chat_set_grab_focus_on_update(!show);	/* Normal keyboard focus when visible */
 	if (show) {
 		gtk_widget_show(trade_page);
-		gtk_notebook_set_current_page(GTK_NOTEBOOK(map_notebook), TRADE_PAGE);
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(map_notebook),
+					      TRADE_PAGE);
 	} else
 		gtk_widget_hide(trade_page);
 }
 
 void gui_show_quote_page(gboolean show)
 {
-	chat_set_grab_focus_on_update(!show); /* Normal keyboard focus when visible */
+	chat_set_grab_focus_on_update(!show);	/* Normal keyboard focus when visible */
 	if (show) {
 		gtk_widget_show(quote_page);
-		gtk_notebook_set_current_page(GTK_NOTEBOOK(map_notebook), QUOTE_PAGE);
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(map_notebook),
+					      QUOTE_PAGE);
 	} else
 		gtk_widget_hide(quote_page);
 }
@@ -447,7 +465,8 @@ void gui_show_legend_page(gboolean show)
 {
 	if (show) {
 		gtk_widget_show(legend_page);
-		gtk_notebook_set_current_page(GTK_NOTEBOOK(map_notebook), LEGEND_PAGE);
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(map_notebook),
+					      LEGEND_PAGE);
 	} else
 		gtk_widget_hide(legend_page);
 }
@@ -457,7 +476,8 @@ void gui_show_splash_page(gboolean show)
 	chat_set_grab_focus_on_update(TRUE);
 	if (show) {
 		gtk_widget_show(splash_page);
-		gtk_notebook_set_current_page(GTK_NOTEBOOK(map_notebook), SPLASH_PAGE);
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(map_notebook),
+					      SPLASH_PAGE);
 	} else
 		gtk_widget_hide(splash_page);
 }
@@ -468,20 +488,16 @@ static GtkWidget *splash_build_page(void)
 	GtkWidget *viewport;
 	gchar *filename;
 
-	filename = gnome_program_locate_file(NULL,
-			GNOME_FILE_DOMAIN_APP_PIXMAP,
-			GNOCATAN_PIXMAP_SPLASH, TRUE, NULL);
-	if (filename==NULL) {
-		pm = gtk_image_new_from_file(GNOCATAN_PIXMAP_SPLASH);
-	} else {
-		pm = gtk_image_new_from_file(filename);
-		g_free(filename);
-	}
+	filename = g_build_filename(DATADIR, "pixmaps", "gnocatan",
+				    "splash.png", NULL);
+	pm = gtk_image_new_from_file(filename);
+	g_free(filename);
 
 	/* The viewport avoids that the pixmap is drawn up into the tab area if
 	 * it's too large for the space provided. */
 	viewport = gtk_viewport_new(NULL, NULL);
-	gtk_viewport_set_shadow_type(GTK_VIEWPORT(viewport), GTK_SHADOW_NONE);
+	gtk_viewport_set_shadow_type(GTK_VIEWPORT(viewport),
+				     GTK_SHADOW_NONE);
 	gtk_widget_show(viewport);
 	gtk_widget_set_size_request(pm, 1, 1);
 	gtk_widget_show(pm);
@@ -541,33 +557,33 @@ static GtkWidget *build_map_panel(void)
 
 void gui_discard_show()
 {
-        gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 1);
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 1);
 }
 
 void gui_discard_hide()
 {
-        gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 0);
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 0);
 }
 
 void gui_gold_show()
 {
-        gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 2);
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 2);
 }
 
 void gui_gold_hide()
 {
-        gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 0);
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 0);
 }
 
-void gui_prompt_show(gchar *message)
+void gui_prompt_show(gchar * message)
 {
 	gtk_label_set_text(GTK_LABEL(prompt_lbl), message);
-        gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 3);
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 3);
 }
 
 void gui_prompt_hide()
 {
-        gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 0);
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(develop_notebook), 0);
 }
 
 static GtkWidget *prompt_build_page(void)
@@ -581,7 +597,8 @@ static GtkWidget *build_develop_panel(void)
 {
 	develop_notebook = gtk_notebook_new();
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(develop_notebook), FALSE);
-	gtk_notebook_set_show_border(GTK_NOTEBOOK(develop_notebook), FALSE);
+	gtk_notebook_set_show_border(GTK_NOTEBOOK(develop_notebook),
+				     FALSE);
 	gtk_widget_show(develop_notebook);
 
 	gtk_notebook_insert_page(GTK_NOTEBOOK(develop_notebook),
@@ -623,8 +640,7 @@ static GtkWidget *build_main_interface(void)
 	gtk_widget_show(vpaned);
 	gtk_paned_pack2(GTK_PANED(hpaned), vpaned, TRUE, TRUE);
 
-	gtk_paned_pack1(GTK_PANED(vpaned),
-			build_map_panel(), TRUE, TRUE);
+	gtk_paned_pack1(GTK_PANED(vpaned), build_map_panel(), TRUE, TRUE);
 
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox);
@@ -640,12 +656,14 @@ static GtkWidget *build_main_interface(void)
 	return hpaned;
 }
 
-static void quit_cb(UNUSED(GtkWidget *widget), UNUSED(void *data))
+static void quit_cb(UNUSED(GtkWidget * widget), UNUSED(void *data))
 {
 	gtk_main_quit();
 }
 
-static void theme_change_cb(UNUSED(GtkMenuItem *widget), gpointer user_data) {
+static void theme_change_cb(UNUSED(GtkMenuItem * widget),
+			    gpointer user_data)
+{
 	MapTheme *theme = user_data;
 	if (theme != get_theme()) {
 		config_set_string("settings/theme", theme->name);
@@ -654,36 +672,46 @@ static void theme_change_cb(UNUSED(GtkMenuItem *widget), gpointer user_data) {
 			g_object_unref(gmap->pixmap);
 			gmap->pixmap = NULL;
 		}
-		theme_rescale(2*gmap->x_point);
-		gtk_widget_queue_draw_area(gmap->area, 0, 0, gmap->width, gmap->height);
+		theme_rescale(2 * gmap->x_point);
+		gtk_widget_queue_draw_area(gmap->area, 0, 0, gmap->width,
+					   gmap->height);
 		gtk_widget_queue_draw(legend_page);
 	}
 }
 
-static void show_legend_cb(GtkToggleButton *widget, UNUSED(gpointer user_data)) {
+static void show_legend_cb(GtkToggleButton * widget,
+			   UNUSED(gpointer user_data))
+{
 	legend_page_enabled = gtk_toggle_button_get_active(widget);
 	gui_show_legend_page(legend_page_enabled);
 	config_set_int("settings/legend_page", legend_page_enabled);
 }
 
-static void message_color_cb(GtkToggleButton *widget, UNUSED(gpointer user_data)) {
+static void message_color_cb(GtkToggleButton * widget,
+			     UNUSED(gpointer user_data))
+{
 	color_messages_enabled = gtk_toggle_button_get_active(widget);
 	config_set_int("settings/color_messages", color_messages_enabled);
 	log_set_func_message_color_enable(color_messages_enabled);
 }
 
-static void chat_color_cb(GtkToggleButton *widget, UNUSED(gpointer user_data)) {
+static void chat_color_cb(GtkToggleButton * widget,
+			  UNUSED(gpointer user_data))
+{
 	color_chat_enabled = gtk_toggle_button_get_active(widget);
 	config_set_int("settings/color_chat", color_chat_enabled);
 }
 
-static void summary_color_cb(GtkToggleButton *widget, UNUSED(gpointer user_data)) {
+static void summary_color_cb(GtkToggleButton * widget,
+			     UNUSED(gpointer user_data))
+{
 	gboolean color_summary = gtk_toggle_button_get_active(widget);
 	config_set_int("settings/color_summary", color_summary);
 	set_color_summary(color_summary);
 }
 
-static void preferences_cb(UNUSED(GtkWidget *widget), UNUSED(void *user_data))
+static void preferences_cb(UNUSED(GtkWidget * widget),
+			   UNUSED(void *user_data))
 {
 	GtkWidget *dlg_vbox;
 	GtkWidget *theme_label;
@@ -694,7 +722,7 @@ static void preferences_cb(UNUSED(GtkWidget *widget), UNUSED(void *user_data))
 
 	gint row;
 	gint color_summary;
-	MapTheme *theme;
+	GList *theme;
 	int i;
 
 	if (preferences_dlg != NULL) {
@@ -703,19 +731,24 @@ static void preferences_cb(UNUSED(GtkWidget *widget), UNUSED(void *user_data))
 	};
 
 	preferences_dlg = gtk_dialog_new_with_buttons(
-			/* Caption of preferences dialog */
-			_("Gnocatan Preferences"),
-			GTK_WINDOW(app_window),
-			GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-			NULL);
-	gtk_dialog_set_default_response(GTK_DIALOG(preferences_dlg), GTK_RESPONSE_CLOSE);
+							     /* Caption of preferences dialog */
+							     _
+							     ("Gnocatan Preferences"),
+							     GTK_WINDOW
+							     (app_window),
+							     GTK_DIALOG_DESTROY_WITH_PARENT,
+							     GTK_STOCK_CLOSE,
+							     GTK_RESPONSE_CLOSE,
+							     NULL);
+	gtk_dialog_set_default_response(GTK_DIALOG(preferences_dlg),
+					GTK_RESPONSE_CLOSE);
 	g_signal_connect(G_OBJECT(preferences_dlg), "destroy",
-			G_CALLBACK(gtk_widget_destroyed), &preferences_dlg);
+			 G_CALLBACK(gtk_widget_destroyed),
+			 &preferences_dlg);
 	g_signal_connect(G_OBJECT(preferences_dlg), "response",
-			G_CALLBACK(gtk_widget_destroy), NULL);
+			 G_CALLBACK(gtk_widget_destroy), NULL);
 	gtk_widget_show(preferences_dlg);
-	
+
 	tooltips = gtk_tooltips_new();
 
 	dlg_vbox = GTK_DIALOG(preferences_dlg)->vbox;
@@ -736,142 +769,145 @@ static void preferences_cb(UNUSED(GtkWidget *widget), UNUSED(void *user_data))
 	gtk_widget_show(theme_menu);
 	gtk_widget_show(theme_list);
 	gtk_widget_show(theme_label);
-	
-	for(i = 0, theme = first_theme(); theme; ++i, theme = next_theme(theme)) {
-		GtkWidget *item = gtk_menu_item_new_with_label(theme->name);
+
+	for (i = 0, theme = first_theme(); theme;
+	     ++i, theme = next_theme(theme)) {
+		GtkWidget *item =
+		    gtk_menu_item_new_with_label(((MapTheme *) theme->
+						  data)->name);
 		gtk_widget_show(item);
 		gtk_menu_append(GTK_MENU(theme_menu), item);
-		if (theme == get_theme())
+		if (theme->data == get_theme())
 			gtk_menu_set_active(GTK_MENU(theme_menu), i);
-		g_signal_connect(G_OBJECT(item), "activate", 
-			G_CALLBACK(theme_change_cb), theme);
+		g_signal_connect(G_OBJECT(item), "activate",
+				 G_CALLBACK(theme_change_cb), theme->data);
 	}
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(theme_list), theme_menu);
-	
-	gtk_table_attach_defaults(GTK_TABLE(layout), theme_label, 
-			0, 1, row, row + 1);
-	gtk_table_attach_defaults(GTK_TABLE(layout), theme_list, 
-			1, 2, row, row + 1);
+
+	gtk_table_attach_defaults(GTK_TABLE(layout), theme_label,
+				  0, 1, row, row + 1);
+	gtk_table_attach_defaults(GTK_TABLE(layout), theme_list,
+				  1, 2, row, row + 1);
 	gtk_tooltips_set_tip(tooltips, theme_list,
-			/* Tooltip for changing the theme in the preferences dialog */
-			_("Choose one of the themes"), NULL);
+			     /* Tooltip for changing the theme in the preferences dialog */
+			     _("Choose one of the themes"), NULL);
 	row++;
 
 	widget = gtk_check_button_new_with_label(
-			/* Label for the option to show the legend */
-			_("Show legend"));
+							/* Label for the option to show the legend */
+							_("Show legend"));
 	gtk_widget_show(widget);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), 
-			legend_page_enabled);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
+				     legend_page_enabled);
 	g_signal_connect(G_OBJECT(widget), "toggled",
-			G_CALLBACK(show_legend_cb), NULL);
-	gtk_table_attach_defaults(GTK_TABLE(layout), widget, 
-			0, 2, row, row + 1);
+			 G_CALLBACK(show_legend_cb), NULL);
+	gtk_table_attach_defaults(GTK_TABLE(layout), widget,
+				  0, 2, row, row + 1);
 	gtk_tooltips_set_tip(tooltips, widget,
-			/* Tooltip for the option to show the legend */
-			_("Show the legend as a page beside the map"), NULL);
+			     /* Tooltip for the option to show the legend */
+			     _("Show the legend as a page beside the map"),
+			     NULL);
 	row++;
 
 	widget = gtk_check_button_new_with_label(
-			/* Label for the option to display log messages in color */
-			_("Messages with color"));
+							/* Label for the option to display log messages in color */
+							_
+							("Messages with color"));
 	gtk_widget_show(widget);
-	gtk_table_attach_defaults(GTK_TABLE(layout), widget, 
-			0, 2, row, row + 1);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), 
-			color_messages_enabled);
+	gtk_table_attach_defaults(GTK_TABLE(layout), widget,
+				  0, 2, row, row + 1);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
+				     color_messages_enabled);
 	g_signal_connect(G_OBJECT(widget), "toggled",
-			G_CALLBACK(message_color_cb), NULL);
+			 G_CALLBACK(message_color_cb), NULL);
 	gtk_tooltips_set_tip(tooltips, widget,
-			/* Tooltip for the option to display log messages in color */
-			_("Show new messages with color"), NULL);
+			     /* Tooltip for the option to display log messages in color */
+			     _("Show new messages with color"), NULL);
 	row++;
 
 	widget = gtk_check_button_new_with_label(
-			/* Label for the option to display chat in color of player */
-			_("Chat in color of player"));
+							/* Label for the option to display chat in color of player */
+							_
+							("Chat in color of player"));
 	gtk_widget_show(widget);
-	gtk_table_attach_defaults(GTK_TABLE(layout), widget, 
-			0, 2, row, row + 1);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), color_chat_enabled);
+	gtk_table_attach_defaults(GTK_TABLE(layout), widget,
+				  0, 2, row, row + 1);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
+				     color_chat_enabled);
 	g_signal_connect(G_OBJECT(widget), "toggled",
-			G_CALLBACK(chat_color_cb), NULL);
+			 G_CALLBACK(chat_color_cb), NULL);
 	gtk_tooltips_set_tip(tooltips, widget,
-			/* Tooltip for the option to display chat in color of player */
-			_("Show new chat messages in the color of the player"), NULL);
+			     /* Tooltip for the option to display chat in color of player */
+			     _
+			     ("Show new chat messages in the color of the player"),
+			     NULL);
 	row++;
 
 	widget = gtk_check_button_new_with_label(
-			/* Label for the option to display the summary with colors */
-			_("Summary with color"));
+							/* Label for the option to display the summary with colors */
+							_
+							("Summary with color"));
 	gtk_widget_show(widget);
-	gtk_table_attach_defaults(GTK_TABLE(layout), widget, 
-			0, 2, row, row + 1);
-	color_summary = config_get_int_with_default("settings/color_summary", TRUE);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), color_summary); /* @todo RC use correct variable */
+	gtk_table_attach_defaults(GTK_TABLE(layout), widget,
+				  0, 2, row, row + 1);
+	color_summary =
+	    config_get_int_with_default("settings/color_summary", TRUE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), color_summary);	/* @todo RC use correct variable */
 	g_signal_connect(G_OBJECT(widget), "toggled",
-			G_CALLBACK(summary_color_cb), NULL);
+			 G_CALLBACK(summary_color_cb), NULL);
 	gtk_tooltips_set_tip(tooltips, widget,
-			/* Tooltip for the option to display the summary with colors */
-			_("Use colors in the player summary"), NULL);
+			     /* Tooltip for the option to display the summary with colors */
+			     _("Use colors in the player summary"), NULL);
 	row++;
 }
 
-static void route_widget_event (UNUSED(GtkWidget *w), gpointer data)
+static void route_widget_event(UNUSED(GtkWidget * w), gpointer data)
 {
-	route_gui_event ( (GuiEvent)data);
+	route_gui_event((GuiEvent) data);
 }
 
-static void help_about_cb(UNUSED(GtkWidget *widget), UNUSED(void *user_data))
+static void help_about_cb(UNUSED(GtkWidget * widget),
+			  UNUSED(void *user_data))
 {
-	GtkWidget *about;
 	const gchar *authors[] = {
 		AUTHORLIST
 	};
-
-	about = gnome_about_new(
-			/* About title */
-			_("The Gnocatan Game"), VERSION,
-			/* About copyright */
-			_("(C) 2002 the Free Software Foundation"),
-			/* About description */
-			_("Gnocatan is based upon the excellent"
-			  " Settlers of Catan board game"),
-			authors,
-			NULL, /* documenters */
-			NULL, /* translators */
-			NULL  /* logo */
-			);
-	gtk_widget_show(about);
+	aboutbox_display(_("The Gnocatan Game"), authors);
 }
 
-static void help_legend_cb(UNUSED(GtkWidget *widget), UNUSED(void *user_data))
+static void help_legend_cb(UNUSED(GtkWidget * widget),
+			   UNUSED(void *user_data))
 {
 	legend_create_dlg();
 }
 
-static void help_histogram_cb(UNUSED(GtkWidget *widget),
-		UNUSED(void *user_data))
+static void help_histogram_cb(UNUSED(GtkWidget * widget),
+			      UNUSED(void *user_data))
 {
 	histogram_create_dlg();
 }
 
-static void help_settings_cb(UNUSED(GtkWidget *widget), UNUSED(void *user_data))
+static void help_settings_cb(UNUSED(GtkWidget * widget),
+			     UNUSED(void *user_data))
 {
 	settings_create_dlg();
 }
 
-static void register_uiinfo(GnomeUIInfo *uiinfo)
+static void register_uiinfo(GnomeUIInfo * uiinfo)
 {
 	while (uiinfo->type != GNOME_APP_UI_ENDOFINFO) {
 		if (uiinfo->type == GNOME_APP_UI_ITEM
-				&& uiinfo->user_data != NULL) {
-			if (uiinfo->user_data != (gpointer)GUI_QUIT)
-				frontend_gui_register (uiinfo->widget,
-					   (GuiEvent)uiinfo->user_data, NULL);
+		    && uiinfo->user_data != NULL) {
+			if (uiinfo->user_data != (gpointer) GUI_QUIT)
+				frontend_gui_register(uiinfo->widget,
+						      (GuiEvent) uiinfo->
+						      user_data, NULL);
 			else
-				frontend_gui_register_destroy (uiinfo->widget,
-					   (GuiEvent)uiinfo->user_data);
+				frontend_gui_register_destroy(uiinfo->
+							      widget,
+							      (GuiEvent)
+							      uiinfo->
+							      user_data);
 		}
 		uiinfo++;
 	}
@@ -883,7 +919,7 @@ static void show_uiinfo(EventType event, gboolean show)
 
 	while (uiinfo->type != GNOME_APP_UI_ENDOFINFO) {
 		if (uiinfo->type == GNOME_APP_UI_ITEM
-		    && (EventType)uiinfo->user_data == event) {
+		    && (EventType) uiinfo->user_data == event) {
 			if (show)
 				gtk_widget_show(uiinfo->widget);
 			else
@@ -894,7 +930,7 @@ static void show_uiinfo(EventType event, gboolean show)
 	}
 }
 
-void gui_set_game_params(const GameParams *params)
+void gui_set_game_params(const GameParams * params)
 {
 	gmap->map = params->map;
 	gtk_widget_queue_resize(gmap->area);
@@ -903,11 +939,12 @@ void gui_set_game_params(const GameParams *params)
 	show_uiinfo(GUI_SHIP, params->num_build_type[BUILD_SHIP] > 0);
 	show_uiinfo(GUI_MOVE_SHIP, params->num_build_type[BUILD_SHIP] > 0);
 	show_uiinfo(GUI_BRIDGE, params->num_build_type[BUILD_BRIDGE] > 0);
-	show_uiinfo(GUI_SETTLEMENT, params->num_build_type[BUILD_SETTLEMENT] > 0);
+	show_uiinfo(GUI_SETTLEMENT,
+		    params->num_build_type[BUILD_SETTLEMENT] > 0);
 	show_uiinfo(GUI_CITY, params->num_build_type[BUILD_CITY] > 0);
 	identity_draw();
 
-	gui_set_vp_target_value( params->victory_points );
+	gui_set_vp_target_value(params->victory_points);
 }
 
 static GtkWidget *build_status_bar(void)
@@ -920,15 +957,16 @@ static GtkWidget *build_status_bar(void)
 
 	vp_target_status = gtk_label_new(" ");
 	gtk_widget_show(vp_target_status);
-	gtk_box_pack_start(GTK_BOX(app_bar), vp_target_status, FALSE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(app_bar), vp_target_status, FALSE, TRUE,
+			   0);
 
 	vsep = gtk_vseparator_new();
 	gtk_widget_show(vsep);
 	gtk_box_pack_start(GTK_BOX(app_bar), vsep, FALSE, TRUE, 0);
 
 	net_status = gtk_label_new(
-			/* Network status: offline */
-			_("Offline"));
+					  /* Network status: offline */
+					  _("Offline"));
 	gtk_widget_show(net_status);
 	gtk_box_pack_start(GTK_BOX(app_bar), net_status, FALSE, TRUE, 0);
 
@@ -940,8 +978,8 @@ static GtkWidget *build_status_bar(void)
 			   player_build_turn_area(), FALSE, TRUE, 0);
 
 	gui_set_instructions(
-			/* Initial text in status bar */
-			_("Welcome to Gnocatan!"));
+				    /* Initial text in status bar */
+				    _("Welcome to Gnocatan!"));
 
 	return app_bar;
 }
@@ -957,35 +995,30 @@ static void register_gnocatan_pixmaps(void)
 		GtkIconSet *icon;
 
 		icon = gtk_icon_set_new();
-
-		/* determine full path to pixmap file...
-		 * this will be APP_DATADIR "/pixmaps/" pixmap_filename
-		 * or e.g. APP_DATADIR "/pixmaps/gnocatan/dice.png" */
-		filename = gnome_program_locate_file(NULL,
-				GNOME_FILE_DOMAIN_APP_PIXMAP,
-				gnocatan_pixmaps[idx], TRUE, NULL);
-		if (filename != NULL) {
+		/* determine full path to pixmap file */
+		filename = g_build_filename(DATADIR, "pixmaps",
+					    gnocatan_pixmaps[idx], NULL);
+		if (g_file_test(filename, G_FILE_TEST_EXISTS)) {
 			GtkIconSource *source;
 			source = gtk_icon_source_new();
 			gtk_icon_source_set_filename(source, filename);
-			g_free(filename);
 			gtk_icon_set_add_source(icon, source);
-		}
-		else {
+			gtk_icon_source_free(source);
+		} else {
 			/* Missing pixmap */
-			fprintf(stderr, _("Warning: pixmap not found: %s\n"),
-					gnocatan_pixmaps[idx]);
+			g_warning(_("Pixmap not found: %s\n"), filename);
 		}
 
-		gtk_icon_factory_add(factory,
-				gnocatan_pixmaps[idx],
-				icon);
+		gtk_icon_factory_add(factory, gnocatan_pixmaps[idx], icon);
+		g_free(filename);
+		gtk_icon_set_unref(icon);
 	}
 
 	gtk_icon_factory_add_default(factory);
+	g_object_unref(factory);
 }
 
-GtkWidget* gui_build_interface()
+GtkWidget *gui_build_interface()
 {
 	gchar *icon_file;
 
@@ -994,48 +1027,47 @@ GtkWidget* gui_build_interface()
 	gmap = guimap_new();
 
 	register_gnocatan_pixmaps();
-	app_window = gnome_app_new("gnocatan", 
-			/* The name of the application */
-			_("Gnocatan"));
+	app_window = gnome_app_new("gnocatan",
+				   /* The name of the application */
+				   _("Gnocatan"));
 
-	icon_file = gnome_program_locate_file(NULL,
-			GNOME_FILE_DOMAIN_APP_PIXMAP,
-			GNOCATAN_ICON_FILE,
-			TRUE, NULL);
-	if (icon_file != NULL) {
+
+	icon_file =
+	    g_build_filename(DATADIR, "pixmaps", GNOCATAN_ICON_FILE, NULL);
+	if (g_file_test(icon_file, G_FILE_TEST_EXISTS)) {
 		gtk_window_set_default_icon_from_file(icon_file, NULL);
-		g_free(icon_file);
-	}
-	else {
+	} else {
 		/* Missing pixmap, main icon file */
-		fprintf(stderr, _("Warning: pixmap not found: %s\n"),
-				GNOCATAN_ICON_FILE);
+		g_warning(_("Pixmap not found: %s\n"), icon_file);
 	}
-	
+	g_free(icon_file);
+
 	gtk_widget_realize(app_window);
 	g_signal_connect(G_OBJECT(app_window), "delete_event",
-			G_CALLBACK(quit_cb), NULL);
-	
-	color_chat_enabled = 
+			 G_CALLBACK(quit_cb), NULL);
+
+	color_chat_enabled =
 	    config_get_int_with_default("settings/color_chat", TRUE);
 
-	color_messages_enabled = 
+	color_messages_enabled =
 	    config_get_int_with_default("settings/color_messages", TRUE);
 	log_set_func_message_color_enable(color_messages_enabled);
 
-	set_color_summary(config_get_int_with_default("settings/color_summary", TRUE));
+	set_color_summary(config_get_int_with_default
+			  ("settings/color_summary", TRUE));
 
-	legend_page_enabled = 
+	legend_page_enabled =
 	    config_get_int_with_default("settings/legend_page", FALSE);
 
 	gnome_app_create_menus(GNOME_APP(app_window), main_menu);
 	gnome_app_create_toolbar(GNOME_APP(app_window), toolbar_uiinfo);
-        
-	gnome_app_set_contents(GNOME_APP(app_window), build_main_interface());
+
+	gnome_app_set_contents(GNOME_APP(app_window),
+			       build_main_interface());
 	build_status_bar();
 
 	g_signal_connect(G_OBJECT(app_window), "key_press_event",
-			G_CALLBACK(hotkeys_handler), NULL);
+			 G_CALLBACK(hotkeys_handler), NULL);
 
 	gtk_widget_show(app_window);
 
