@@ -27,7 +27,7 @@
 static void trade_update(void);
 
 typedef struct {
-	GtkWidget *chk; /**< Checkbox to activate trade in this resource */
+	GtkWidget *chk;	/**< Checkbox to activate trade in this resource */
 	GtkWidget *curr; /**< Amount in possession of this resource */
 	Resource resource; /**< The resource */
 	gboolean enabled; /**< Trading enabled */
@@ -41,8 +41,8 @@ enum {
 	TRADE_COLUMN_REJECT, /**< Internal data: contains the rejected players. Not for display */
 	TRADE_COLUMN_PLAYER_NUM, /**< The player number, or -1 for maritime trade */
 	TRADE_COLUMN_LAST
-	};
-	
+};
+
 /** The data for the GUI */
 static GtkListStore *store;
 /** The widget */
@@ -81,7 +81,7 @@ static GdkPixbuf *player_pixbuf[MAX_PLAYERS];
 static GdkPixbuf *maritime_pixbuf;
 
 /** @return TRUE is we can accept this domestic quote */
-static gboolean is_good_quote(QuoteInfo *quote)
+static gboolean is_good_quote(QuoteInfo * quote)
 {
 	gint idx;
 	g_assert(quote != NULL);
@@ -113,7 +113,7 @@ gboolean can_call_for_quotes()
 	/* don't require both supply and receive, for resources may be
 	 * given away for free */
 	return (have_we_receive || have_we_supply)
-		&& can_trade_domestic ();
+	    && can_trade_domestic();
 }
 
 /** @return the current quote */
@@ -123,7 +123,7 @@ QuoteInfo *trade_current_quote()
 }
 
 /** Show what the resources will be if the quote is accepted */
-static void update_rows(void) 
+static void update_rows(void)
 {
 	gint idx;
 	gint amount;
@@ -135,26 +135,33 @@ static void update_rows(void)
 		if (!trade_valid_selection())
 			amount = 0;
 		else if (quote->is_domestic)
-			amount = quote->var.d.receive[idx] - quote->var.d.supply[idx];
+			amount =
+			    quote->var.d.receive[idx] -
+			    quote->var.d.supply[idx];
 		else
-			amount = (quote->var.m.supply == resource ? quote->var.m.ratio : 0)
-				- (quote->var.m.receive == resource ? 1 : 0);
+			amount =
+			    (quote->var.m.supply ==
+			     resource ? quote->var.m.ratio : 0)
+			    - (quote->var.m.receive == resource ? 1 : 0);
 		sprintf(str, "%d", resource_asset(resource) - amount);
-		gtk_label_set_text(GTK_LABEL(we_receive_rows[idx].curr), str);
-		gtk_label_set_text(GTK_LABEL(we_supply_rows[idx].curr), str);
+		gtk_label_set_text(GTK_LABEL(we_receive_rows[idx].curr),
+				   str);
+		gtk_label_set_text(GTK_LABEL(we_supply_rows[idx].curr),
+				   str);
 	}
 }
 
 /** Activate a new quote. 
  * If the quote == NULL, clear the selection in the listview too */
-static void set_selected_quote(QuoteInfo *quote) 
+static void set_selected_quote(QuoteInfo * quote)
 {
 	if (selected_quote == quote)
-		return; /* Don't do the same thing again */
+		return;		/* Don't do the same thing again */
 
 	selected_quote = quote;
 	if (quote == NULL)
-		gtk_tree_selection_unselect_all(gtk_tree_view_get_selection(GTK_TREE_VIEW(quotes)));
+		gtk_tree_selection_unselect_all(gtk_tree_view_get_selection
+						(GTK_TREE_VIEW(quotes)));
 	update_rows();
 }
 
@@ -199,34 +206,46 @@ static void load_pixmaps(void)
 	GdkGC *gc;
 	gint i;
 
-	if (init) return;
+	if (init)
+		return;
 
 	gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &width, &height);
 
-	pixmap = gdk_pixmap_new(quotes->window, width, height, gtk_widget_get_visual(quotes)->depth);
+	pixmap =
+	    gdk_pixmap_new(quotes->window, width, height,
+			   gtk_widget_get_visual(quotes)->depth);
 
 	gc = gdk_gc_new(pixmap);
 	gdk_gc_set_foreground(gc, &black);
 	gdk_draw_rectangle(pixmap, gc, TRUE, 0, 0, width, height);
 	for (i = 0; i < MAX_PLAYERS; ++i) {
 		gdk_gc_set_foreground(gc, player_color(i));
-		gdk_draw_rectangle(pixmap, gc, TRUE, 1, 1, width-2, height-2);
-		player_pixbuf[i] = gdk_pixbuf_get_from_drawable(NULL, pixmap, NULL, 0, 0, 0, 0, -1, -1);
+		gdk_draw_rectangle(pixmap, gc, TRUE, 1, 1, width - 2,
+				   height - 2);
+		player_pixbuf[i] =
+		    gdk_pixbuf_get_from_drawable(NULL, pixmap, NULL, 0, 0,
+						 0, 0, -1, -1);
 	}
 	gdk_gc_set_fill(gc, GDK_TILED);
 	/** @todo RC Should be updated when the theme changes */
 	gdk_gc_set_tile(gc, guimap_terrain(SEA_TERRAIN));
 	gdk_draw_rectangle(pixmap, gc, TRUE, 0, 0, width, height);
-	maritime_pixbuf = gdk_pixbuf_get_from_drawable(NULL, pixmap, NULL, 0, 0, 0, 0,
--1, -1);
+	maritime_pixbuf =
+	    gdk_pixbuf_get_from_drawable(NULL, pixmap, NULL, 0, 0, 0, 0,
+					 -1, -1);
+	g_object_unref(gc);
 
-	cross_pixbuf = gtk_widget_render_icon(quotes, GTK_STOCK_CANCEL, GTK_ICON_SIZE_MENU, NULL);
-	tick_pixbuf = gtk_widget_render_icon(quotes, GTK_STOCK_APPLY, GTK_ICON_SIZE_MENU, NULL);
+	cross_pixbuf =
+	    gtk_widget_render_icon(quotes, GTK_STOCK_CANCEL,
+				   GTK_ICON_SIZE_MENU, NULL);
+	tick_pixbuf =
+	    gtk_widget_render_icon(quotes, GTK_STOCK_APPLY,
+				   GTK_ICON_SIZE_MENU, NULL);
 
 	init = TRUE;
 }
 
-static void format_list(gchar *desc, gint *resources)
+static void format_list(gchar * desc, gint * resources)
 {
 	gint idx;
 	gboolean is_first;
@@ -246,7 +265,7 @@ static void format_list(gchar *desc, gint *resources)
 		}
 }
 
-static gboolean empty_list(gint *resources)
+static gboolean empty_list(gint * resources)
 {
 	gint idx;
 
@@ -256,7 +275,7 @@ static gboolean empty_list(gint *resources)
 	return TRUE;
 }
 
-void trade_format_quote(QuoteInfo *quote, gchar *desc)
+void trade_format_quote(QuoteInfo * quote, gchar * desc)
 {
 	gchar *format = NULL;
 	gchar buf1[128];
@@ -281,7 +300,7 @@ void trade_format_quote(QuoteInfo *quote, gchar *desc)
 	}
 }
 
-static void trade_format_maritime(QuoteInfo *quote, gchar *desc)
+static void trade_format_maritime(QuoteInfo * quote, gchar * desc)
 {
 	/* trade: maritime quote: %1 resources of type %2 for
 	 * one resource of type %3 */
@@ -294,8 +313,9 @@ static void trade_format_maritime(QuoteInfo *quote, gchar *desc)
 /** Locate the QuoteInfo* in user_data. Return TRUE if is found. The iter
  *  is set in quote_found_iter. The flag quote_found_flag is set to TRUE
  */
-static gboolean trade_locate_quote(GtkTreeModel *model, UNUSED(GtkTreePath *path), 
-		GtkTreeIter *iter, gpointer user_data)
+static gboolean trade_locate_quote(GtkTreeModel * model,
+				   UNUSED(GtkTreePath * path),
+				   GtkTreeIter * iter, gpointer user_data)
 {
 	QuoteInfo *wanted = user_data;
 	QuoteInfo *current;
@@ -313,13 +333,14 @@ static gboolean trade_locate_quote(GtkTreeModel *model, UNUSED(GtkTreePath *path
  *  When quote_found_flag == TRUE, use _insert_before on quote_found_iter.
  *  When quote_found_flag == FALSE, use _append.
  */
-static gboolean trade_locate_player(GtkTreeModel *model, 
-		UNUSED(GtkTreePath *path), GtkTreeIter *iter, 
-		gpointer user_data)
+static gboolean trade_locate_player(GtkTreeModel * model,
+				    UNUSED(GtkTreePath * path),
+				    GtkTreeIter * iter, gpointer user_data)
 {
 	int wanted = GPOINTER_TO_INT(user_data);
 	int current;
-	gtk_tree_model_get(model, iter, TRADE_COLUMN_PLAYER_NUM, &current, -1);
+	gtk_tree_model_get(model, iter, TRADE_COLUMN_PLAYER_NUM, &current,
+			   -1);
 	if (current > wanted) {
 		quote_found_flag = TRUE;
 		quote_found_iter = *iter;
@@ -327,12 +348,13 @@ static gboolean trade_locate_player(GtkTreeModel *model,
 	}
 	return FALSE;
 }
+
 /** Locate the Player* in user_data. Return TRUE if is found. The iter
  *  is set in quote_found_iter. The flag quote_found_flag is set to TRUE
  */
-static gboolean trade_locate_reject(GtkTreeModel *model, 
-		UNUSED(GtkTreePath *path), GtkTreeIter *iter, 
-		gpointer user_data)
+static gboolean trade_locate_reject(GtkTreeModel * model,
+				    UNUSED(GtkTreePath * path),
+				    GtkTreeIter * iter, gpointer user_data)
 {
 	Player *wanted = user_data;
 	Player *current;
@@ -346,7 +368,8 @@ static gboolean trade_locate_reject(GtkTreeModel *model,
 }
 
 /** Add a maritime trade */
-static void add_maritime_trade(gint ratio, Resource receive, Resource supply)
+static void add_maritime_trade(gint ratio, Resource receive,
+			       Resource supply)
 {
 	QuoteInfo *quote;
 	QuoteInfo *prev;
@@ -361,7 +384,7 @@ static void add_maritime_trade(gint ratio, Resource receive, Resource supply)
 			 && quote->var.m.supply == supply
 			 && quote->var.m.receive == receive)
 			return;
-	
+
 	quote = quotelist_add_maritime(quote_list, ratio, supply, receive);
 
 	trade_format_maritime(quote, quote_desc);
@@ -369,29 +392,27 @@ static void add_maritime_trade(gint ratio, Resource receive, Resource supply)
 
 	quote_found_flag = FALSE;
 	if (prev != NULL)
-		gtk_tree_model_foreach(GTK_TREE_MODEL(store), trade_locate_quote, prev);
+		gtk_tree_model_foreach(GTK_TREE_MODEL(store),
+				       trade_locate_quote, prev);
 	if (quote_found_flag)
-		gtk_list_store_insert_after(store, &iter, &quote_found_iter);
+		gtk_list_store_insert_after(store, &iter,
+					    &quote_found_iter);
 	else
 		gtk_list_store_prepend(store, &iter);
-	gtk_list_store_set( store, &iter,
-			TRADE_COLUMN_PLAYER, maritime_pixbuf,
-			TRADE_COLUMN_POSSIBLE, tick_pixbuf,
-			TRADE_COLUMN_DESCRIPTION, quote_desc,
-			TRADE_COLUMN_QUOTE, quote,
-			TRADE_COLUMN_PLAYER_NUM, -1, /* Maritime trade */
-			-1);
+	gtk_list_store_set(store, &iter, TRADE_COLUMN_PLAYER, maritime_pixbuf, TRADE_COLUMN_POSSIBLE, tick_pixbuf, TRADE_COLUMN_DESCRIPTION, quote_desc, TRADE_COLUMN_QUOTE, quote, TRADE_COLUMN_PLAYER_NUM, -1,	/* Maritime trade */
+			   -1);
 }
 
 /** Remove a quote from the list */
-static void remove_quote(QuoteInfo *quote)
+static void remove_quote(QuoteInfo * quote)
 {
 	if (quote == selected_quote)
 		set_selected_quote(NULL);
 
 	quote_found_flag = FALSE;
-	gtk_tree_model_foreach(GTK_TREE_MODEL(store), trade_locate_quote, quote);
-	if (quote_found_flag) 
+	gtk_tree_model_foreach(GTK_TREE_MODEL(store), trade_locate_quote,
+			       quote);
+	if (quote_found_flag)
 		gtk_list_store_remove(store, &quote_found_iter);
 	quotelist_delete(quote_list, quote);
 }
@@ -404,8 +425,9 @@ static void add_reject_row(gint player_num)
 	GtkTreeIter iter;
 
 	quote_found_flag = FALSE;
-	gtk_tree_model_foreach(GTK_TREE_MODEL(store), trade_locate_reject, player);
-	if (quote_found_flag) /* Already removed */
+	gtk_tree_model_foreach(GTK_TREE_MODEL(store), trade_locate_reject,
+			       player);
+	if (quote_found_flag)	/* Already removed */
 		return;
 
 	/* work out where to put the reject row
@@ -419,20 +441,20 @@ static void add_reject_row(gint player_num)
 
 	quote_found_flag = FALSE;
 	gtk_tree_model_foreach(GTK_TREE_MODEL(store), trade_locate_player,
-			GINT_TO_POINTER(player_num));
+			       GINT_TO_POINTER(player_num));
 	if (quote_found_flag)
-		gtk_list_store_insert_before(store, &iter, &quote_found_iter);
+		gtk_list_store_insert_before(store, &iter,
+					     &quote_found_iter);
 	else
 		gtk_list_store_append(store, &iter);
-	gtk_list_store_set( store, &iter,
-			TRADE_COLUMN_PLAYER, player_pixbuf[player_num],
-			TRADE_COLUMN_POSSIBLE, cross_pixbuf,
-			/* Trade: a player has rejected trade */
-			TRADE_COLUMN_DESCRIPTION, _("Rejected trade"),
-			TRADE_COLUMN_QUOTE, NULL,
-			TRADE_COLUMN_REJECT, player,
-			TRADE_COLUMN_PLAYER_NUM, player_num,
-			-1);
+	gtk_list_store_set(store, &iter,
+			   TRADE_COLUMN_PLAYER, player_pixbuf[player_num],
+			   TRADE_COLUMN_POSSIBLE, cross_pixbuf,
+			   /* Trade: a player has rejected trade */
+			   TRADE_COLUMN_DESCRIPTION, _("Rejected trade"),
+			   TRADE_COLUMN_QUOTE, NULL,
+			   TRADE_COLUMN_REJECT, player,
+			   TRADE_COLUMN_PLAYER_NUM, player_num, -1);
 }
 
 /** A new trade is started. Keep old quotes, and remove rejection messages.
@@ -444,10 +466,11 @@ void trade_new_trade()
 	gchar we_receive_desc[512];
 	gchar desc[512];
 
-	for (idx = 0; idx < num_players (); idx++) {
+	for (idx = 0; idx < num_players(); idx++) {
 		Player *player = player_get(idx);
 		quote_found_flag = FALSE;
-		gtk_tree_model_foreach(GTK_TREE_MODEL(store), trade_locate_reject, player);
+		gtk_tree_model_foreach(GTK_TREE_MODEL(store),
+				       trade_locate_reject, player);
 		if (quote_found_flag)
 			gtk_list_store_remove(store, &quote_found_iter);
 	}
@@ -483,15 +506,22 @@ static void check_maritime_trades(void)
 		if (we_receive_rows[curr->var.m.receive].enabled)
 			switch (curr->var.m.ratio) {
 			case 2:
-				is_valid = maritime_info.specific_resource[curr->var.m.supply]
-					&& resource_asset(curr->var.m.supply) >= 2;
+				is_valid =
+				    maritime_info.specific_resource[curr->
+								    var.m.
+								    supply]
+				    && resource_asset(curr->var.m.
+						      supply) >= 2;
 				break;
 			case 3:
 				is_valid = maritime_info.any_resource
-					&& resource_asset(curr->var.m.supply) >= 3;
+				    && resource_asset(curr->var.m.
+						      supply) >= 3;
 				break;
 			case 4:
-				is_valid = resource_asset(curr->var.m.supply) >= 4;
+				is_valid =
+				    resource_asset(curr->var.m.supply) >=
+				    4;
 				break;
 			}
 		if (!is_valid)
@@ -506,7 +536,8 @@ static void check_maritime_trades(void)
 		if (!we_receive_rows[idx].enabled)
 			continue;
 
-		for (supply_idx = 0; supply_idx < NO_RESOURCE; supply_idx++) {
+		for (supply_idx = 0; supply_idx < NO_RESOURCE;
+		     supply_idx++) {
 			if (supply_idx == idx)
 				continue;
 			if (maritime_info.specific_resource[supply_idx]
@@ -528,16 +559,18 @@ static void check_maritime_trades(void)
 }
 
 /** A resource checkbox is toggled */
-static void toggled_cb(GtkWidget *widget, TradeRow *row)
+static void toggled_cb(GtkWidget * widget, TradeRow * row)
 {
-	row->enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
+	row->enabled =
+	    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 	set_selected_quote(NULL);
 	trade_update();
 	frontend_gui_update();
 }
 
 /** Add a row with widgets for a resource */
-static void add_trade_row(GtkWidget *table, TradeRow* row, Resource resource)
+static void add_trade_row(GtkWidget * table, TradeRow * row,
+			  Resource resource)
 {
 	GtkWidget *label;
 	gint col;
@@ -545,12 +578,14 @@ static void add_trade_row(GtkWidget *table, TradeRow* row, Resource resource)
 
 	col = 0;
 	row->resource = resource;
-	row->chk = gtk_check_button_new_with_label(resource_name(resource, TRUE));
-	g_signal_connect(G_OBJECT(row->chk), "toggled", G_CALLBACK(toggled_cb), row);
+	row->chk =
+	    gtk_check_button_new_with_label(resource_name(resource, TRUE));
+	g_signal_connect(G_OBJECT(row->chk), "toggled",
+			 G_CALLBACK(toggled_cb), row);
 	gtk_widget_show(row->chk);
 	gtk_table_attach(GTK_TABLE(table), row->chk,
-			col, col + 1, resource, resource + 1,
-			GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+			 col, col + 1, resource, resource + 1,
+			 GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 	col++;
 
 	/* Draw a border around the number */
@@ -558,8 +593,8 @@ static void add_trade_row(GtkWidget *table, TradeRow* row, Resource resource)
 	gtk_viewport_set_shadow_type(GTK_VIEWPORT(frame), GTK_SHADOW_IN);
 	gtk_widget_show(frame);
 	gtk_table_attach(GTK_TABLE(table), frame,
-			col, col + 1, resource, resource + 1,
-			GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+			 col, col + 1, resource, resource + 1,
+			 GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
 	/* Reserve space for 2 digits */
 	row->curr = label = gtk_label_new("00");
@@ -570,26 +605,28 @@ static void add_trade_row(GtkWidget *table, TradeRow* row, Resource resource)
 }
 
 /** Set the sensitivity of the row, and update the assets when applicable */
-static void set_row_sensitive(TradeRow *row)
+static void set_row_sensitive(TradeRow * row)
 {
-	gtk_widget_set_sensitive(row->chk, resource_asset(row->resource) > 0);
+	gtk_widget_set_sensitive(row->chk,
+				 resource_asset(row->resource) > 0);
 }
 
 /** Check if the quote still is valid. Update the icon.
  */
-static gboolean check_valid_trade(GtkTreeModel *model, 
-		UNUSED(GtkTreePath *path), GtkTreeIter *iter, 
-		UNUSED(gpointer user_data))
+static gboolean check_valid_trade(GtkTreeModel * model,
+				  UNUSED(GtkTreePath * path),
+				  GtkTreeIter * iter,
+				  UNUSED(gpointer user_data))
 {
 	QuoteInfo *quote;
 	gtk_tree_model_get(model, iter, TRADE_COLUMN_QUOTE, &quote, -1);
 	if (quote != NULL)
 		if (quote->is_domestic) {
-			gtk_list_store_set( store, iter,
-				TRADE_COLUMN_POSSIBLE, is_good_quote(quote) ?
-					tick_pixbuf : cross_pixbuf,
-				-1);
-	}
+			gtk_list_store_set(store, iter,
+					   TRADE_COLUMN_POSSIBLE,
+					   is_good_quote(quote) ?
+					   tick_pixbuf : cross_pixbuf, -1);
+		}
 	return FALSE;
 }
 
@@ -600,34 +637,38 @@ static void trade_update(void)
 
 	for (idx = 0; idx < numElem(we_supply_rows); idx++) {
 		if (resource_asset(idx) == 0) {
-			gtk_toggle_button_set_active(
-					GTK_TOGGLE_BUTTON(we_supply_rows[idx].chk),
-					FALSE);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+						     (we_supply_rows[idx].
+						      chk), FALSE);
 			we_supply_rows[idx].enabled = FALSE;
 		}
 		set_row_sensitive(we_supply_rows + idx);
 	}
 	check_maritime_trades();
-	
+
 	/* Check if all quotes are still valid */
-	gtk_tree_model_foreach(GTK_TREE_MODEL(store), check_valid_trade, NULL);
+	gtk_tree_model_foreach(GTK_TREE_MODEL(store), check_valid_trade,
+			       NULL);
 }
 
 /** Actions before a domestic trade is performed */
 void trade_perform_domestic(UNUSED(gint player_num), gint partner_num,
-		gint quote_num, gint *they_supply, gint *they_receive)
+			    gint quote_num, gint * they_supply,
+			    gint * they_receive)
 {
 	cb_trade(partner_num, quote_num, they_supply, they_receive);
 }
 
 /** Actions after a domestic trade is performed */
 void frontend_trade_domestic(gint partner_num, gint quote_num,
-		UNUSED (gint *we_supply), UNUSED (gint *we_receive) )
+			     UNUSED(gint * we_supply),
+			     UNUSED(gint * we_receive))
 {
 	QuoteInfo *quote;
 
 	g_assert(quote_list != NULL);
-	quote = quotelist_find_domestic(quote_list, partner_num, quote_num);
+	quote =
+	    quotelist_find_domestic(quote_list, partner_num, quote_num);
 	g_assert(quote != NULL);
 	remove_quote(quote);
 	trade_update();
@@ -636,12 +677,13 @@ void frontend_trade_domestic(gint partner_num, gint quote_num,
 /** Actions before a maritime trade is performed */
 void trade_perform_maritime(gint ratio, Resource supply, Resource receive)
 {
-	cb_maritime (ratio, supply, receive);
+	cb_maritime(ratio, supply, receive);
 }
 
 /** Actions after a maritime trade is performed */
-void frontend_trade_maritime(UNUSED (gint ratio), UNUSED (Resource we_supply),
-		UNUSED (Resource we_receive) )
+void frontend_trade_maritime(UNUSED(gint ratio),
+			     UNUSED(Resource we_supply),
+			     UNUSED(Resource we_receive))
 {
 	set_selected_quote(NULL);
 	trade_update();
@@ -649,35 +691,37 @@ void frontend_trade_maritime(UNUSED (gint ratio), UNUSED (Resource we_supply),
 
 /** Add a quote from a player */
 void trade_add_quote(gint player_num,
-		     gint quote_num, gint *supply, gint *receive)
+		     gint quote_num, gint * supply, gint * receive)
 {
 	QuoteInfo *quote;
 	gchar quote_desc[128];
 	GtkTreeIter iter;
 
 	/* If the trade is already listed, don't duplicate */
-	if (quotelist_find_domestic(quote_list, player_num, quote_num) != NULL)
+	if (quotelist_find_domestic(quote_list, player_num, quote_num) !=
+	    NULL)
 		return;
 
 	quote = quotelist_add_domestic(quote_list,
-			player_num, quote_num, supply, receive);
+				       player_num, quote_num, supply,
+				       receive);
 	trade_format_quote(quote, quote_desc);
-     
+
 	quote_found_flag = FALSE;
 	gtk_tree_model_foreach(GTK_TREE_MODEL(store), trade_locate_player,
-			GINT_TO_POINTER(player_num));
+			       GINT_TO_POINTER(player_num));
 	if (quote_found_flag)
-		gtk_list_store_insert_before(store, &iter, &quote_found_iter);
+		gtk_list_store_insert_before(store, &iter,
+					     &quote_found_iter);
 	else
 		gtk_list_store_append(store, &iter);
-	gtk_list_store_set( store, &iter,
-			TRADE_COLUMN_PLAYER, player_pixbuf[player_num],
-			TRADE_COLUMN_POSSIBLE, is_good_quote(quote) ?
-				tick_pixbuf : cross_pixbuf,
-			TRADE_COLUMN_DESCRIPTION, quote_desc,
-			TRADE_COLUMN_QUOTE, quote,
-			TRADE_COLUMN_PLAYER_NUM, player_num,
-			-1);
+	gtk_list_store_set(store, &iter,
+			   TRADE_COLUMN_PLAYER, player_pixbuf[player_num],
+			   TRADE_COLUMN_POSSIBLE, is_good_quote(quote) ?
+			   tick_pixbuf : cross_pixbuf,
+			   TRADE_COLUMN_DESCRIPTION, quote_desc,
+			   TRADE_COLUMN_QUOTE, quote,
+			   TRADE_COLUMN_PLAYER_NUM, player_num, -1);
 }
 
 void trade_delete_quote(gint player_num, gint quote_num)
@@ -697,9 +741,11 @@ void trade_delete_quote(gint player_num, gint quote_num)
 void trade_player_finish(gint player_num)
 {
 	QuoteInfo *quote;
-	while ((quote = quotelist_find_domestic(quote_list, player_num, -1)) != NULL) {
+	while ((quote =
+		quotelist_find_domestic(quote_list, player_num,
+					-1)) != NULL) {
 		remove_quote(quote);
-		}
+	}
 	add_reject_row(player_num);
 }
 
@@ -721,19 +767,19 @@ void trade_begin()
 	quotelist_new(&quote_list);
 
 	for (idx = 0; idx < numElem(we_supply_rows); idx++) {
-		gtk_toggle_button_set_active(
-				GTK_TOGGLE_BUTTON(we_supply_rows[idx].chk),
-				FALSE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+					     (we_supply_rows[idx].chk),
+					     FALSE);
 		we_supply_rows[idx].enabled = FALSE;
 		set_row_sensitive(we_supply_rows + idx);
-		gtk_toggle_button_set_active(
-				GTK_TOGGLE_BUTTON(we_receive_rows[idx].chk),
-				FALSE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+					     (we_receive_rows[idx].chk),
+					     FALSE);
 		we_receive_rows[idx].enabled = FALSE;
 	}
 	gtk_list_store_clear(store);
 
-	if (!can_trade_domestic () ) {
+	if (!can_trade_domestic()) {
 		gtk_widget_hide(we_receive_frame);
 		gtk_widget_hide(call_btn);
 		gtk_widget_hide(active_quote_label);
@@ -744,12 +790,13 @@ void trade_begin()
 		gtk_label_set_text(GTK_LABEL(active_quote_label), "");
 	}
 	set_selected_quote(NULL);
-	update_rows(); /* Always update */
+	update_rows();		/* Always update */
 	gui_show_trade_page(TRUE);
 }
 
-static gint quote_click_cb(UNUSED(GtkWidget *widget),
-		UNUSED(GdkEventButton *event), UNUSED(gpointer user_data))
+static gint quote_click_cb(UNUSED(GtkWidget * widget),
+			   UNUSED(GdkEventButton * event),
+			   UNUSED(gpointer user_data))
 {
 	if (event->type == GDK_2BUTTON_PRESS) {
 		if (trade_valid_selection())
@@ -758,7 +805,8 @@ static gint quote_click_cb(UNUSED(GtkWidget *widget),
 	return FALSE;
 }
 
-static void quote_select_cb(GtkTreeSelection *selection, UNUSED(gpointer user_data))
+static void quote_select_cb(GtkTreeSelection * selection,
+			    UNUSED(gpointer user_data))
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model;
@@ -766,7 +814,8 @@ static void quote_select_cb(GtkTreeSelection *selection, UNUSED(gpointer user_da
 
 	g_assert(selection != NULL);
 	if (gtk_tree_selection_get_selected(selection, &model, &iter))
-		gtk_tree_model_get(model, &iter, TRADE_COLUMN_QUOTE, &quote, -1);
+		gtk_tree_model_get(model, &iter, TRADE_COLUMN_QUOTE,
+				   &quote, -1);
 	else
 		quote = NULL;
 	set_selected_quote(quote);
@@ -774,7 +823,7 @@ static void quote_select_cb(GtkTreeSelection *selection, UNUSED(gpointer user_da
 }
 
 /** Build the page */
-GtkWidget *trade_build_page (void)
+GtkWidget *trade_build_page(void)
 {
 	GtkWidget *panel_mainbox;
 	GtkWidget *panel_hbox;
@@ -795,12 +844,14 @@ GtkWidget *trade_build_page (void)
 	active_quote_label = gtk_label_new("");
 	gtk_widget_show(active_quote_label);
 	gtk_misc_set_alignment(GTK_MISC(active_quote_label), 0, 0.5);
-	gtk_box_pack_start(GTK_BOX(panel_mainbox), active_quote_label, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(panel_mainbox), active_quote_label,
+			   FALSE, FALSE, 0);
 
 	panel_hbox = gtk_hbox_new(FALSE, 5);
 	gtk_widget_show(panel_hbox);
-	gtk_box_pack_start(GTK_BOX(panel_mainbox), panel_hbox, TRUE, TRUE, 0);
-	
+	gtk_box_pack_start(GTK_BOX(panel_mainbox), panel_hbox, TRUE, TRUE,
+			   0);
+
 	vbox = gtk_vbox_new(FALSE, 3);
 	gtk_widget_show(vbox);
 	gtk_box_pack_start(GTK_BOX(panel_hbox), vbox, FALSE, TRUE, 0);
@@ -823,7 +874,8 @@ GtkWidget *trade_build_page (void)
 	/* Frame title, trade: I want these resources in return */
 	we_receive_frame = gtk_frame_new(_("Give Them"));
 	gtk_widget_show(we_receive_frame);
-	gtk_box_pack_start(GTK_BOX(vbox), we_receive_frame, FALSE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), we_receive_frame, FALSE, TRUE,
+			   0);
 
 	table = gtk_table_new(NO_RESOURCE, 2, FALSE);
 	gtk_widget_show(table);
@@ -840,7 +892,7 @@ GtkWidget *trade_build_page (void)
 
 	/* Button text, trade: call for quotes from other players */
 	call_btn = gtk_button_new_with_mnemonic(_("_Call for Quotes"));
-	frontend_gui_register (call_btn, GUI_TRADE_CALL, "clicked");
+	frontend_gui_register(call_btn, GUI_TRADE_CALL, "clicked");
 	gtk_widget_show(call_btn);
 	gtk_container_add(GTK_CONTAINER(bbox), call_btn);
 
@@ -850,21 +902,20 @@ GtkWidget *trade_build_page (void)
 
 	/* Create model */
 	store = gtk_list_store_new(TRADE_COLUMN_LAST,
-		GDK_TYPE_PIXBUF,
-		GDK_TYPE_PIXBUF,
-		G_TYPE_STRING,
-		G_TYPE_POINTER,
-		G_TYPE_POINTER,
-		G_TYPE_INT
-		);
+				   GDK_TYPE_PIXBUF,
+				   GDK_TYPE_PIXBUF,
+				   G_TYPE_STRING,
+				   G_TYPE_POINTER,
+				   G_TYPE_POINTER, G_TYPE_INT);
 
 	scroll_win = gtk_scrolled_window_new(NULL, NULL);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(scroll_win),
-			GTK_SHADOW_IN);
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW
+					    (scroll_win), GTK_SHADOW_IN);
 	gtk_widget_show(scroll_win);
 	gtk_box_pack_start(GTK_BOX(vbox), scroll_win, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll_win),
-			GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+				       GTK_POLICY_NEVER,
+				       GTK_POLICY_AUTOMATIC);
 
 	/* Create graphical representation of the model */
 	quotes = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
@@ -872,30 +923,41 @@ GtkWidget *trade_build_page (void)
 
 	/* Register double-click */
 	g_signal_connect(G_OBJECT(quotes), "button_press_event",
-			G_CALLBACK(quote_click_cb), NULL);
+			 G_CALLBACK(quote_click_cb), NULL);
 
-	g_signal_connect(
-			G_OBJECT(gtk_tree_view_get_selection(GTK_TREE_VIEW(quotes))),
-			"changed", G_CALLBACK(quote_select_cb), NULL);
+	g_signal_connect(G_OBJECT
+			 (gtk_tree_view_get_selection
+			  (GTK_TREE_VIEW(quotes))), "changed",
+			 G_CALLBACK(quote_select_cb), NULL);
 
 	/* Now create columns */
 	column = gtk_tree_view_column_new_with_attributes(
-			/* Table header: Player who trades */
-			_("Player"),
-			gtk_cell_renderer_pixbuf_new(), "pixbuf", 
-			TRADE_COLUMN_PLAYER, NULL);
+								 /* Table header: Player who trades */
+								 _
+								 ("Player"),
+								 gtk_cell_renderer_pixbuf_new
+								 (),
+								 "pixbuf",
+								 TRADE_COLUMN_PLAYER,
+								 NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(quotes), column);
 
 	column = gtk_tree_view_column_new_with_attributes("",
-			gtk_cell_renderer_pixbuf_new(), "pixbuf",
-			TRADE_COLUMN_POSSIBLE, NULL);
+							  gtk_cell_renderer_pixbuf_new
+							  (), "pixbuf",
+							  TRADE_COLUMN_POSSIBLE,
+							  NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(quotes), column);
 
 	column = gtk_tree_view_column_new_with_attributes(
-			/* Table header: Quote */
-			_("Quotes"),
-			gtk_cell_renderer_text_new(), "text", 
-			TRADE_COLUMN_DESCRIPTION,  NULL);
+								 /* Table header: Quote */
+								 _
+								 ("Quotes"),
+								 gtk_cell_renderer_text_new
+								 (),
+								 "text",
+								 TRADE_COLUMN_DESCRIPTION,
+								 NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(quotes), column);
 	gtk_widget_show(quotes);
 
@@ -905,16 +967,18 @@ GtkWidget *trade_build_page (void)
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_END);
 
 	accept_btn = gtk_button_new_with_mnemonic(
-			/* Button text: Trade page, accept selected quote */
-			_("_Accept Quote"));
-	frontend_gui_register (accept_btn, GUI_TRADE_ACCEPT, "clicked");
+							 /* Button text: Trade page, accept selected quote */
+							 _
+							 ("_Accept Quote"));
+	frontend_gui_register(accept_btn, GUI_TRADE_ACCEPT, "clicked");
 	gtk_widget_show(accept_btn);
 	gtk_container_add(GTK_CONTAINER(bbox), accept_btn);
 
 	finish_btn = gtk_button_new_with_mnemonic(
-			/* Button text: Trade page, finish trading */
-			_("_Finish Trading"));
-	frontend_gui_register (finish_btn, GUI_TRADE_FINISH, "clicked");
+							 /* Button text: Trade page, finish trading */
+							 _
+							 ("_Finish Trading"));
+	frontend_gui_register(finish_btn, GUI_TRADE_FINISH, "clicked");
 	gtk_widget_show(finish_btn);
 	gtk_container_add(GTK_CONTAINER(bbox), finish_btn);
 
