@@ -19,31 +19,13 @@
  */
 
 #include "config.h"
-#include <fcntl.h>
-#include <ctype.h>
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
 #include <netdb.h>
-#include <errno.h>
-#include <glib.h>
-
-#include "game.h"
-#include "cards.h"
-#include "map.h"
-#include "buildrec.h"
-#include "network.h"
-#include "cost.h"
-#include "log.h"
 #include "server.h"
 
 const gchar *meta_server_name = NULL;
-gchar *hostname = NULL;
 
 static Session *ses;
 static enum {
@@ -56,6 +38,15 @@ static gint meta_server_version_major;
 static gint meta_server_version_minor;
 static gint num_redirects;
 
+gchar *get_server_name(void)
+{
+	gchar *server_name;
+	server_name = g_strdup(g_getenv("GNOCATAN_SERVER_NAME"));
+	if (!server_name)
+		server_name = get_my_hostname();
+	return server_name;
+}
+
 void meta_start_game()
 {
 #ifdef CLOSE_META_AT_START
@@ -73,7 +64,7 @@ void meta_report_num_players(gint num_players)
 		net_printf(ses, "curr=%d\n", num_players);
 }
 
-void meta_send_details(Game *game)
+void meta_send_details(Game * game)
 {
 	if (ses == NULL)
 		return;
@@ -84,33 +75,42 @@ void meta_send_details(Game *game)
 		   "version=%s\n"
 		   "max=%d\n"
 		   "curr=%d\n",
-		   game->params->server_port, PROTOCOL_VERSION,
+		   game->server_port, PROTOCOL_VERSION,
 		   game->params->num_players, game->num_players);
-	if (hostname)
-	    net_printf(ses, "host=%s\n", hostname);
-	if (meta_server_version_major >= 1) {
-	    net_printf(ses,
-		       "vpoints=%d\n"
-		       "sevenrule=%s\n"
-		       "terrain=%s\n"
-		       "title=%s\n",
-		       game->params->victory_points,
-		       game->params->sevens_rule == 0 ? "normal" :
-		       game->params->sevens_rule == 1 ? "reroll first 2" :
-							"reroll all",
-		       game->params->random_terrain ? "random" : "default",
-		       game->params->title);
+	/* Hostname is empty */
+	if (game->hostname && !strlen(game->hostname)) {
+		g_free(game->hostname);
+		game->hostname = NULL;
 	}
-	else {
-	    net_printf(ses,
-		       "map=%s\n"
-		       "comment=%s\n",
-		       game->params->random_terrain ? "random" : "default",
-		       game->params->title);
+	/* No hostname set, use default */
+	if (!game->hostname) {
+		game->hostname = get_server_name();
+	}
+	net_printf(ses, "host=%s\n", game->hostname);
+	if (meta_server_version_major >= 1) {
+		net_printf(ses,
+			   "vpoints=%d\n"
+			   "sevenrule=%s\n"
+			   "terrain=%s\n"
+			   "title=%s\n",
+			   game->params->victory_points,
+			   game->params->sevens_rule == 0 ? "normal" :
+			   game->params->sevens_rule ==
+			   1 ? "reroll first 2" : "reroll all",
+			   game->params->
+			   random_terrain ? "random" : "default",
+			   game->params->title);
+	} else {
+		net_printf(ses,
+			   "map=%s\n"
+			   "comment=%s\n",
+			   game->params->
+			   random_terrain ? "random" : "default",
+			   game->params->title);
 	}
 }
-			   
-static void meta_event(NetEvent event, Game *game, char *line)
+
+static void meta_event(NetEvent event, Game * game, char *line)
 {
 	switch (event) {
 	case NET_READ:
@@ -125,29 +125,43 @@ static void meta_event(NetEvent event, Game *game, char *line)
 				net_close(ses);
 				ses = NULL;
 				if (num_redirects++ == 10) {
-					log_message( MSG_INFO, _("Too many meta-server redirects\n"));
+					log_message(MSG_INFO,
+						    _
+						    ("Too many meta-server redirects\n"));
 					return;
 				}
-				if (sscanf(line, "goto %s %s", server, port) == 2)
+				if (sscanf
+				    (line, "goto %s %s", server,
+				     port) == 2)
 					meta_register(server, port, game);
-				else if (sscanf(line, "goto %s", server) == 1)
-					meta_register(server, GNOCATAN_DEFAULT_META_PORT, game);
+				else if (sscanf(line, "goto %s", server) ==
+					 1)
+					meta_register(server,
+						      GNOCATAN_DEFAULT_META_PORT,
+						      game);
 				else
-					log_message( MSG_ERROR, _("Bad redirect line: %s\n"), line);
+					log_message(MSG_ERROR,
+						    _
+						    ("Bad redirect line: %s\n"),
+						    line);
 				break;
 			}
-			meta_server_version_major = meta_server_version_minor = 0;
+			meta_server_version_major =
+			    meta_server_version_minor = 0;
 			if (strncmp(line, "welcome ", 8) == 0) {
 				char *p = strstr(line, "version ");
 				if (p) {
 					p += 8;
-					meta_server_version_major = atoi(p);
+					meta_server_version_major =
+					    atoi(p);
 					p += strspn(p, "0123456789");
 					if (*p == '.')
-						meta_server_version_minor = atoi(p+1);
+						meta_server_version_minor =
+						    atoi(p + 1);
 				}
 			}
-			net_printf(ses, "version %s\n", META_PROTOCOL_VERSION);
+			net_printf(ses, "version %s\n",
+				   META_PROTOCOL_VERSION);
 			meta_mode = MODE_SERVER_LIST;
 			meta_send_details(game);
 			break;
@@ -160,7 +174,8 @@ static void meta_event(NetEvent event, Game *game, char *line)
 		break;
 	case NET_CLOSE:
 		if (meta_mode == MODE_SIGNON)
-			log_message( MSG_ERROR, _("Meta-server kicked us off\n"));
+			log_message(MSG_ERROR,
+				    _("Meta-server kicked us off\n"));
 		net_free(&ses);
 		break;
 	case NET_CONNECT:
@@ -169,19 +184,23 @@ static void meta_event(NetEvent event, Game *game, char *line)
 	}
 }
 
-void meta_register(const gchar *server, const gchar *port, Game *game)
+void meta_register(const gchar * server, const gchar * port, Game * game)
 {
 	if (num_redirects > 0)
-		log_message( MSG_INFO, _("Redirected to meta-server at %s, port %s\n"),
-			 server, port);
+		log_message(MSG_INFO,
+			    _
+			    ("Redirected to meta-server at %s, port %s\n"),
+			    server, port);
 	else
-		log_message( MSG_INFO, _("Register with meta-server at %s, port %s\n"),
-			 server, port);
+		log_message(MSG_INFO,
+			    _
+			    ("Register with meta-server at %s, port %s\n"),
+			    server, port);
 
 	if (ses != NULL)
 		net_close(ses);
 
-	ses = net_new((NetNotifyFunc)meta_event, game);
+	ses = net_new((NetNotifyFunc) meta_event, game);
 	if (net_connect(ses, server, port))
 		meta_mode = MODE_SIGNON;
 	else {
