@@ -20,37 +20,20 @@
  */
 
 #include "config.h"
-#include <fcntl.h>
-#include <ctype.h>
 #include <stdio.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <netdb.h>
-#include <errno.h>
 #include <string.h>
-#include <glib.h>
 #include <unistd.h>
-
-#include "game.h"
-#include "cards.h"
-#include "map.h"
-#include "buildrec.h"
-#include "network.h"
-#include "cost.h"
-#include "log.h"
 #include "server.h"
 
 /* Local function prototypes */
-static gboolean mode_check_version(Player *player, gint event);
-static gboolean mode_check_status(Player *player, gint event);
-static gboolean mode_bad_version(Player *player, gint event);
-static gboolean mode_game_is_over(Player *player, gint event);
-static gboolean mode_global(Player *player, gint event);
-static gboolean mode_unhandled(Player *player, gint event);
+static gboolean mode_check_version(Player * player, gint event);
+static gboolean mode_check_status(Player * player, gint event);
+static gboolean mode_bad_version(Player * player, gint event);
+static gboolean mode_game_is_over(Player * player, gint event);
+static gboolean mode_global(Player * player, gint event);
+static gboolean mode_unhandled(Player * player, gint event);
 
-static gint next_player_num(Game *game, gboolean force_viewer)
+static gint next_player_num(Game * game, gboolean force_viewer)
 {
 	gint idx = game->params->num_players;
 
@@ -63,23 +46,38 @@ static gint next_player_num(Game *game, gboolean force_viewer)
 		     list != NULL; list = g_list_next(list)) {
 			Player *player = list->data;
 			if (player->num >= 0
-				&& !player_is_viewer(game, player->num)
-				&& !player->disconnected)
-					players[player->num] = TRUE;
+			    && !player_is_viewer(game, player->num)
+			    && !player->disconnected)
+				players[player->num] = TRUE;
 		}
 		playerlist_dec_use_count(game);
 
-		for (idx = 0; idx < game->params->num_players; idx++)
-			if (!players[idx])
-				break;
+		if (game->random_order) {
+			gint empty = 0, skip;
+			for (idx = 0; idx < game->params->num_players;
+			     idx++)
+				if (!players[idx])
+					empty++;
+			skip = get_rand(empty);
+			for (idx = 0; idx < game->params->num_players;
+			     idx++)
+				if (!players[idx] && skip-- == 0)
+					break;
+		} else {
+			for (idx = 0; idx < game->params->num_players;
+			     idx++)
+				if (!players[idx])
+					break;
+		}
 	}
 	if (idx == game->params->num_players)
-		while (player_by_num (game, idx) != NULL) ++idx;
+		while (player_by_num(game, idx) != NULL)
+			++idx;
 
 	return idx;
 }
 
-static gboolean mode_global(Player *player, gint event)
+static gboolean mode_global(Player * player, gint event)
 {
 	StateMachine *sm = player->sm;
 	Game *game = player->game;
@@ -88,25 +86,23 @@ static gboolean mode_global(Player *player, gint event)
 	switch (event) {
 	case SM_NET_CLOSE:
 		player_remove(player);
-		if (player->num >= 0)
-		{
+		if (player->num >= 0) {
 			player_broadcast(player, PB_OTHERS, "has quit\n");
 			player_archive(player);
-		}
-		else
-		{
+		} else {
 			player_free(player);
 		}
 		driver->player_change(game);
 		return TRUE;
 	case SM_RECV:
-		if (sm_recv(sm, "chat %S", text, sizeof (text))) {
-			player_broadcast(player, PB_ALL, "chat %s\n", text);
+		if (sm_recv(sm, "chat %S", text, sizeof(text))) {
+			player_broadcast(player, PB_ALL, "chat %s\n",
+					 text);
 			return TRUE;
 		}
-		if (sm_recv(sm, "name %S", text, sizeof (text))) {
+		if (sm_recv(sm, "name %S", text, sizeof(text))) {
 			if (text[0] == 0)
-				sm_send (sm, "ERR invalid-name\n");
+				sm_send(sm, "ERR invalid-name\n");
 			else
 				player_set_name(player, text);
 			return TRUE;
@@ -118,16 +114,18 @@ static gboolean mode_global(Player *player, gint event)
 	return FALSE;
 }
 
-static gboolean mode_unhandled (Player *player, gint event)
+static gboolean mode_unhandled(Player * player, gint event)
 {
 	StateMachine *sm = player->sm;
 	gchar text[512];
 
 	switch (event) {
 	case SM_RECV:
-		if (sm_recv (sm, "extension %S", text, sizeof (text) ) ) {
-			sm_send (sm, "NOTE ignoring unknown extension\n");
-			log_message (MSG_INFO, "ignoring unknown extension from %s: %s\n", player->name, text);
+		if (sm_recv(sm, "extension %S", text, sizeof(text))) {
+			sm_send(sm, "NOTE ignoring unknown extension\n");
+			log_message(MSG_INFO,
+				    "ignoring unknown extension from %s: %s\n",
+				    player->name, text);
 			return TRUE;
 		}
 		break;
@@ -143,22 +141,22 @@ static gboolean mode_unhandled (Player *player, gint event)
  */
 static gboolean tournament_start_cb(gpointer data)
 {
-    int i;
-    Player *player = (Player *)data;
-    Game *game = player->game;
+	int i;
+	Player *player = (Player *) data;
+	Game *game = player->game;
+
+	/* if game already started */
+	if (game->num_players == game->params->num_players)
+		return FALSE;
+
+	player_broadcast(player, PB_SILENT,
+			 "NOTE Game starts, adding computer players\n");
+	/* add computer players to start game */
+	for (i = game->num_players; i < game->params->num_players; i++) {
+		new_computer_player(NULL, game->server_port);
+	}
 
-    /* if game already started */
-    if (game->num_players == game->params->num_players)
 	return FALSE;
-
-    player_broadcast(player, PB_SILENT,
-		     "NOTE Game starts, adding computer players\n");
-    /* add computer players to start game */
-    for (i = game->num_players; i < game->params->num_players; i++) {	
-	new_computer_player(NULL, game->params->server_port);
-    }
-
-    return FALSE;
 }
 
 /*
@@ -167,27 +165,27 @@ static gboolean tournament_start_cb(gpointer data)
  */
 static gboolean talk_about_tournament_cb(gpointer data)
 {
-    Player *player = (Player *)data;
-    Game *game = player->game;
+	Player *player = (Player *) data;
+	Game *game = player->game;
+
+	/* if game already started */
+	if (game->num_players == game->params->num_players)
+		return FALSE;
+
+	player_broadcast(player, PB_SILENT,
+			 "NOTE Game starts in %d minute%s\n",
+			 game->params->tournament_time,
+			 game->params->tournament_time != 1 ? "s" : "");
+	game->params->tournament_time--;
+
+	if (game->params->tournament_time > 0)
+		g_timeout_add(1000 * 60,
+			      &talk_about_tournament_cb, player);
 
-    /* if game already started */
-    if (game->num_players == game->params->num_players)
 	return FALSE;
-
-    player_broadcast(player, PB_SILENT, "NOTE Game starts in %d minute%s\n",
-		     game->params->tournament_time,
-		     game->params->tournament_time != 1 ? "s" : "");
-    game->params->tournament_time--;
-    
-    if (game->params->tournament_time > 0)
-	g_timeout_add(1000*60,
-		      &talk_about_tournament_cb,
-		      player);
-
-    return FALSE;
 }
 
-Player *player_new(Game *game, int fd, gchar *location)
+Player *player_new(Game * game, int fd, gchar * location)
 {
 	gchar name[100];
 	gint i;
@@ -195,30 +193,33 @@ Player *player_new(Game *game, int fd, gchar *location)
 	StateMachine *sm;
 
 	/* give player a name, some functions need it */
-	strcpy (name, "connecting");
-	for (i = strlen (name); i < numElem (name) - 1; ++i) {
-		if (player_by_name (game, name) == NULL) break;
+	strcpy(name, "connecting");
+	for (i = strlen(name); i < numElem(name) - 1; ++i) {
+		if (player_by_name(game, name) == NULL)
+			break;
 		name[i] = '_';
 		name[i + 1] = 0;
 	}
-	if (i == numElem (name) - 1) {
+	if (i == numElem(name) - 1) {
 		/* there are too many pending connections */
-		write (fd, "Too many connections\n", 21);
-		close (fd);
+		write(fd, "Too many connections\n", 21);
+		close(fd);
 		return NULL;
 	}
 
 	player = g_malloc0(sizeof(*player));
 	sm = player->sm = sm_new(player);
 
-	sm_global_set(sm, (StateFunc)mode_global);
-	sm_unhandled_set(sm, (StateFunc)mode_unhandled);
+	sm_global_set(sm, (StateFunc) mode_global);
+	sm_unhandled_set(sm, (StateFunc) mode_unhandled);
 	sm_use_fd(sm, fd);
 
 	if (game->is_game_over) {
 		/* The game is over, don't accept new players */
-		sm_goto(sm, (StateFunc)mode_game_is_over);
-		log_message( MSG_INFO, _("Player from %s is refused: game is over\n"), location);
+		sm_goto(sm, (StateFunc) mode_game_is_over);
+		log_message(MSG_INFO,
+			    _("Player from %s is refused: game is over\n"),
+			    location);
 		sm_free(sm);
 		close(fd);
 		return NULL;
@@ -235,20 +236,18 @@ Player *player_new(Game *game, int fd, gchar *location)
 	player->libr_played = 0;
 	player->market_played = 0;
 	player->disconnected = FALSE;
-	player->name = g_strdup (name);
+	player->name = g_strdup(name);
 
 	/* if first player in and this is a tournament start the timer */
-	if ((game->num_players == 0) && (game->params->tournament_time > 0)) {
-	    g_timeout_add(game->params->tournament_time*60*1000+500,
-			  &tournament_start_cb,
-			  player);
-	    g_timeout_add(1000,
-			  &talk_about_tournament_cb,
-			  player);
+	if ((game->num_players == 0)
+	    && (game->params->tournament_time > 0)) {
+		g_timeout_add(game->params->tournament_time * 60 * 1000 +
+			      500, &tournament_start_cb, player);
+		g_timeout_add(1000, &talk_about_tournament_cb, player);
 	}
-	
-	sm_goto(sm, (StateFunc)mode_check_version);
-	
+
+	sm_goto(sm, (StateFunc) mode_check_version);
+
 	driver->player_change(game);
 	return player;
 }
@@ -256,24 +255,25 @@ Player *player_new(Game *game, int fd, gchar *location)
 /* set the player name.  Most of the time, player_set_name is called instead,
  * which calls this function with public set to TRUE.  Only player_setup calls
  * this with public == FALSE, because it doesn't want the broadcast. */
-static void player_set_name_real(Player *player, gchar *name, gboolean public)
+static void player_set_name_real(Player * player, gchar * name,
+				 gboolean public)
 {
 	StateMachine *sm = player->sm;
 	Game *game = player->game;
 
-	g_assert (name[0] != 0);
+	g_assert(name[0] != 0);
 
 	if (player_by_name(game, name) != NULL) {
 		/* make it a note, not an error, so nothing bad happens
 		 * (on error the AI would disconnect) */
-		sm_send (sm, "NOTE %s\n",
-			_("Name not changed: new name is already in use") );
+		sm_send(sm, "NOTE %s\n",
+			_("Name not changed: new name is already in use"));
 		return;
 	}
 
 	if (player->name != name) {
-		g_free (player->name);
-		player->name = g_strdup (name);
+		g_free(player->name);
+		player->name = g_strdup(name);
 	}
 
 	if (public)
@@ -283,8 +283,8 @@ static void player_set_name_real(Player *player, gchar *name, gboolean public)
 	driver->player_change(game);
 }
 
-void player_setup(Player *player, int playernum, gchar *name,
-		gboolean force_viewer)
+void player_setup(Player * player, int playernum, gchar * name,
+		  gboolean force_viewer)
 {
 	gchar nm[100];
 	gchar *namep;
@@ -293,8 +293,7 @@ void player_setup(Player *player, int playernum, gchar *name,
 	Player *other;
 
 	player->num = playernum;
-	if (player->num < 0)
-	{
+	if (player->num < 0) {
 		player->num = next_player_num(game, force_viewer);
 	}
 
@@ -314,61 +313,63 @@ void player_setup(Player *player, int playernum, gchar *name,
 		if (player_is_viewer(game, player->num)) {
 			gint num = 0;
 			do {
-				sprintf (nm, "Viewer %d", num++);
-			} while (player_by_name (game, nm) != NULL);
+				sprintf(nm, "Viewer %d", num++);
+			} while (player_by_name(game, nm) != NULL);
 			namep = nm;
 		} else {
-			sprintf (nm, "Player %d", player->num);
+			sprintf(nm, "Player %d", player->num);
 			namep = nm;
 		}
 	} else
 		namep = name;
 
 	/* if the new name exists, try padding it with underscores */
-	other = player_by_name (game, namep);
+	other = player_by_name(game, namep);
 	if (other != player && other != NULL) {
 		gint i;
 		/* put the name in the buffer, so it is editable */
 		if (namep != nm) {
-			strncpy (nm, namep, sizeof (nm) );
+			strncpy(nm, namep, sizeof(nm));
 			namep = nm;
 		}
 		/* add underscores until the name is unique */
-		for (i = strlen (nm); i < numElem (nm) - 1; ++i) {
-			if (player_by_name (game, nm) == NULL) break;
+		for (i = strlen(nm); i < numElem(nm) - 1; ++i) {
+			if (player_by_name(game, nm) == NULL)
+				break;
 			nm[i] = '_';
 			nm[i + 1] = 0;
 		}
-		if (i == numElem (nm) - 1) {
+		if (i == numElem(nm) - 1) {
 			/* This should never happen */
 			/* use the connection name */
-			strncpy (nm, player->name, sizeof (nm) );
+			strncpy(nm, player->name, sizeof(nm));
 		}
 	}
 	/* copy the (possibly new) name to dynamic memory */
 	/* don't broadcast the name.  This is done by mode_pre_game, after
 	 * telling the user how many players are in the game.
 	 * That should keep things easier for the client. */
-	player_set_name_real (player, namep, FALSE);
+	player_set_name_real(player, namep, FALSE);
 
 	/* add the info in the output device */
 	driver->player_added(player);
 	driver->player_change(game);
 	if (playernum < 0)
-		sm_goto(sm, (StateFunc)mode_pre_game);
+		sm_goto(sm, (StateFunc) mode_pre_game);
 }
 
-void player_free(Player *player)
+void player_free(Player * player)
 {
 	Game *game = player->game;
 
-	if (game->player_list_use_count>0) {
-		game->dead_players = g_list_append(game->dead_players, player);
+	if (game->player_list_use_count > 0) {
+		game->dead_players =
+		    g_list_append(game->dead_players, player);
 		player->disconnected = TRUE;
 		return;
 	}
 
-	game->player_list = g_list_remove (game->player_list, player);
+	game->player_list = g_list_remove(game->player_list, player);
 	driver->player_change(game);
 
 	sm_free(player->sm);
@@ -389,7 +390,7 @@ void player_free(Player *player)
 	g_free(player);
 }
 
-void player_archive(Player *player)
+void player_archive(Player * player)
 {
 	StateFunc state;
 	Game *game = player->game;
@@ -403,26 +404,22 @@ void player_archive(Player *player)
 	/* If the player was in the middle of a trade, pop the state
 	   machine and inform others as necessary */
 	state = sm_current(player->sm);
-	if (state == (StateFunc)mode_wait_quote_exit)
-	{
+	if (state == (StateFunc) mode_wait_quote_exit) {
 		sm_pop(player->sm);
-	} 
-	else if (state == (StateFunc)mode_domestic_quote)
-	{
+	} else if (state == (StateFunc) mode_domestic_quote) {
 		for (;;) {
-			QuoteInfo *quote; 
+			QuoteInfo *quote;
 			quote = quotelist_find_domestic(game->quotes,
 							player->num, -1);
 			if (quote == NULL)
 				break;
 			quotelist_delete(game->quotes, quote);
 		}
-		player_broadcast(player, PB_RESPOND, "domestic-quote finish\n");
+		player_broadcast(player, PB_RESPOND,
+				 "domestic-quote finish\n");
 
 		sm_pop(player->sm);
-	}
-	else if (state == (StateFunc)mode_domestic_initiate)
-	{
+	} else if (state == (StateFunc) mode_domestic_initiate) {
 		trade_finish_domestic(player);
 	}
 
@@ -436,19 +433,20 @@ void player_archive(Player *player)
    newp: Player* attempt to revive this player
    name: The player wants to have this name, if possible
 */
-void player_revive(Player *newp, char *name)
+void player_revive(Player * newp, char *name)
 {
 	Game *game = newp->game;
 	GList *current = NULL;
 	Player *p = NULL;
+	gboolean reviving_player_in_setup;
 
 	/* first see if a player with the given name exists */
 	if (name) {
 		playerlist_inc_use_count(game);
 		for (current = game->player_list; current != NULL;
-				current = g_list_next (current) ) {
+		     current = g_list_next(current)) {
 			p = current->data;
-			if (!strcmp (name, p->name) )
+			if (!strcmp(name, p->name))
 				if (p->disconnected && p != newp)
 					break;
 		}
@@ -458,48 +456,29 @@ void player_revive(Player *newp, char *name)
 	if (current == NULL) {
 		playerlist_inc_use_count(game);
 		for (current = game->player_list; current != NULL;
-				current = g_list_next (current) ) {
+		     current = g_list_next(current)) {
 			p = current->data;
-			if (p->disconnected && p != newp) break;
+			if (p->disconnected && p != newp)
+				break;
 		}
 		playerlist_dec_use_count(game);
 	}
 	/* if still no player is found, do a normal setup */
 	if (current == NULL) {
-		player_setup (newp, -1, name, FALSE);
+		player_setup(newp, -1, name, FALSE);
 		return;
 	}
 
+	/* Reviving the player that is currently in the setup phase */
+	reviving_player_in_setup =
+	    (game->setup_player && game->setup_player->data == p);
+
 	/* remove the disconnected player from the player list, it's memory will be freed at the end of this routine */
-	game->player_list = g_list_remove (game->player_list, p);
+	game->player_list = g_list_remove(game->player_list, p);
 
 	/* initialize the player */
 	player_setup(newp, p->num, name, FALSE);
 
-#if 0
-	/* if the player is in the wrong position in
-	   the list, remove the player from the end of
-	   the list and insert him at the appropriate
-	   place */
-	if (newp->num < game->params->num_players - 1) {
-		game->player_list = g_list_remove(game->player_list, newp);
-		playerlist_inc_use_count(game);
-		for (currp = game->player_list;
-		     currp != NULL;
-		     currp = g_list_next(currp)) {
-			if (newp->num < ((Player *)currp->data)->num) {
-				game->player_list = g_list_insert(game->player_list, newp, g_list_index(game->player_list, currp->data));
-				break;
-			}
-		}
-		playerlist_dec_use_count(game);
-		if (!currp) {
-			game->player_list = g_list_append(game->player_list, newp);
-		}
-	driver->player_change(game);
-	}
-#endif
-
 	/* mark the player as a reconnect */
 	newp->disconnected = TRUE;
 
@@ -507,16 +486,15 @@ void player_revive(Player *newp, char *name)
 
 	/* copy over all the data from p */
 	newp->build_list = p->build_list;
-	p->build_list = NULL; /* prevent deletion */
+	p->build_list = NULL;	/* prevent deletion */
 	memcpy(newp->prev_assets, p->prev_assets,
 	       sizeof(newp->prev_assets));
-	memcpy(newp->assets, p->assets,
-	       sizeof(newp->assets));
+	memcpy(newp->assets, p->assets, sizeof(newp->assets));
 	newp->gold = p->gold;
 	newp->devel = p->devel;
-	p->devel = NULL; /* prevent deletion */
+	p->devel = NULL;	/* prevent deletion */
 	newp->points = p->points;
-	p->points = NULL; /* prevent deletion */
+	p->points = NULL;	/* prevent deletion */
 	newp->discard_num = p->discard_num;
 	newp->num_roads = p->num_roads;
 	newp->num_bridges = p->num_bridges;
@@ -532,14 +510,15 @@ void player_revive(Player *newp, char *name)
 	newp->libr_played = p->libr_played;
 	newp->market_played = p->market_played;
 	/* Not copied: sm, game, location, num, client_version */
-	
+
 	/* copy over the state */
-	memcpy(newp->sm->stack, p->sm->stack,
-	       sizeof(newp->sm->stack));
+	memcpy(newp->sm->stack, p->sm->stack, sizeof(newp->sm->stack));
+	memcpy(newp->sm->stack_name, p->sm->stack_name,
+	       sizeof(newp->sm->stack_name));
 	newp->sm->stack_ptr = p->sm->stack_ptr;
 	newp->sm->current_state = p->sm->current_state;
 
-	sm_push(newp->sm, (StateFunc)mode_pre_game);
+	sm_push(newp->sm, (StateFunc) mode_pre_game);
 
 	/* Copy longest road and largest army */
 	if (game->longest_road == p)
@@ -547,38 +526,50 @@ void player_revive(Player *newp, char *name)
 	if (game->largest_army == p)
 		game->largest_army = newp;
 
-	p->num = -1; /* prevent the number of players
-		        from getting decremented */
+	if (reviving_player_in_setup) {
+		/* Restore the pointer */
+		game->setup_player = game->player_list;
+		while (game->setup_player
+		       && game->setup_player->data != newp) {
+			game->setup_player =
+			    g_list_next(game->setup_player);
+		}
+		g_assert(game->setup_player != NULL);
+	}
+	p->num = -1;		/* prevent the number of players
+				   from getting decremented */
 
 	player_free(p);
+
 	player_broadcast(newp, PB_SILENT,
-			_("NOTE player %d (%s) has reconnected.\n"),
+			 _("NOTE player %d (%s) has reconnected.\n"),
 			 newp->num, newp->name);
 	return;
 }
 
-gboolean mode_viewer (Player *player, gint event)
+gboolean mode_viewer(Player * player, gint event)
 {
 	gint num;
 	Game *game = player->game;
 	StateMachine *sm = player->sm;
 	Player *other;
 
-	sm_state_name (sm, "mode_viewer");
-	if (event != SM_RECV) return FALSE;
+	sm_state_name(sm, "mode_viewer");
+	if (event != SM_RECV)
+		return FALSE;
 	/* first see if this is a valid event for this mode */
-	if (sm_recv (sm, "play") ) {
+	if (sm_recv(sm, "play")) {
 		/* try to be the first available player */
-		num = next_player_num (game, FALSE);
+		num = next_player_num(game, FALSE);
 		if (num >= game->params->num_players) {
-			sm_send (sm, "ERR game-full");
+			sm_send(sm, "ERR game-full");
 			return TRUE;
 		}
-	} else if (sm_recv (sm, "play %d", &num) ) {
+	} else if (sm_recv(sm, "play %d", &num)) {
 		/* try to be the specified player number */
 		if (num >= game->params->num_players
-				|| !player_by_num (game, num)->disconnected) {
-			sm_send (sm, "ERR invalid-player");
+		    || !player_by_num(game, num)->disconnected) {
+			sm_send(sm, "ERR invalid-player");
 			return TRUE;
 		}
 	} else
@@ -586,23 +577,23 @@ gboolean mode_viewer (Player *player, gint event)
 		 * see if mode_unhandled likes it */
 		return FALSE;
 
-	other = player_by_num (game, num);
+	other = player_by_num(game, num);
 	if (other == NULL) {
-		sm_send (sm, "Ok\n");
-		player_broadcast (player, PB_ALL, "was viewer %d\n",
-				player->num);
-		player_setup (player, player->num, player->name, FALSE);
-		sm_goto (sm, (StateFunc)mode_pre_game);
+		sm_send(sm, "Ok\n");
+		player_broadcast(player, PB_ALL, "was viewer %d\n",
+				 player->num);
+		player_setup(player, player->num, player->name, FALSE);
+		sm_goto(sm, (StateFunc) mode_pre_game);
 		return TRUE;
 	}
-	player_revive (player, player->name);
+	player_revive(player, player->name);
 	return TRUE;
 }
 
-static gboolean mode_bad_version(Player *player, gint event)
+static gboolean mode_bad_version(Player * player, gint event)
 {
 	StateMachine *sm = player->sm;
-	
+
 	sm_state_name(sm, "mode_bad_version");
 	switch (event) {
 	case SM_ENTER:
@@ -612,7 +603,7 @@ static gboolean mode_bad_version(Player *player, gint event)
 	return FALSE;
 }
 
-static gboolean mode_game_is_over(Player *player, gint event)
+static gboolean mode_game_is_over(Player * player, gint event)
 {
 	StateMachine *sm = player->sm;
 
@@ -625,7 +616,7 @@ static gboolean mode_game_is_over(Player *player, gint event)
 	return FALSE;
 }
 
-static gboolean check_versions( gchar *client_version )
+static gboolean check_versions(gchar * client_version)
 {
 	gchar *p, *v1, *v2;
 	gboolean rv;
@@ -635,10 +626,10 @@ static gboolean check_versions( gchar *client_version )
 	/* ignore rightmost number (after last dot) in versions -- changes
 	 * in patchlevel shouldn't change protocol incompatibly */
 	if ((p = strrchr(v1, '.')))
-	    *p = '\0';
+		*p = '\0';
 	if ((p = strrchr(v2, '.')))
-	    *p = '\0';
-	
+		*p = '\0';
+
 	rv = strcmp(v1, v2) == 0;
 
 	g_free(v1);
@@ -646,27 +637,25 @@ static gboolean check_versions( gchar *client_version )
 	return rv;
 }
 
-static gboolean mode_check_version(Player *player, gint event)
+static gboolean mode_check_version(Player * player, gint event)
 {
 	StateMachine *sm = player->sm;
 	gchar version[512];
-	
+
 	sm_state_name(sm, "mode_check_version");
 	switch (event) {
 	case SM_ENTER:
 		sm_send(sm, "version report\n");
 		break;
-	
+
 	case SM_RECV:
-		if( sm_recv(sm, "version %S", version, sizeof (version)) )
-		{
+		if (sm_recv(sm, "version %S", version, sizeof(version))) {
 			player->client_version = g_strdup(version);
-			if( check_versions( version ) )
-			{
-				sm_goto(sm, (StateFunc)mode_check_status);
+			if (check_versions(version)) {
+				sm_goto(sm, (StateFunc) mode_check_status);
 				return TRUE;
 			} else {
-				sm_goto(sm, (StateFunc)mode_bad_version);
+				sm_goto(sm, (StateFunc) mode_bad_version);
 				return TRUE;
 			}
 		}
@@ -677,35 +666,35 @@ static gboolean mode_check_version(Player *player, gint event)
 	return FALSE;
 }
 
-static gboolean mode_check_status(Player *player, gint event)
+static gboolean mode_check_status(Player * player, gint event)
 {
 	StateMachine *sm = player->sm;
 	gchar playername[512];
-	
+
 	sm_state_name(sm, "mode_check_status");
 	switch (event) {
 	case SM_ENTER:
 		sm_send(sm, "status report\n");
 		break;
-	
+
 	case SM_RECV:
-		if( sm_recv(sm, "status newplayer") ) {
+		if (sm_recv(sm, "status newplayer")) {
 			player_setup(player, -1, NULL, FALSE);
 			return TRUE;
 		}
-		if( sm_recv(sm, "status reconnect %S", playername,
-					sizeof (playername)) ) {
+		if (sm_recv(sm, "status reconnect %S", playername,
+			    sizeof(playername))) {
 			/* if possible, try to revive the player */
 			player_revive(player, playername);
 			return TRUE;
 		}
-		if (sm_recv (sm, "status newviewer") ) {
-			player_setup (player, -1, NULL, TRUE);
+		if (sm_recv(sm, "status newviewer")) {
+			player_setup(player, -1, NULL, TRUE);
 			return TRUE;
 		}
-		if (sm_recv (sm, "status viewer %S", playername,
-					sizeof (playername) ) ) {
-			player_setup (player, -1, playername, TRUE);
+		if (sm_recv(sm, "status viewer %S", playername,
+			    sizeof(playername))) {
+			player_setup(player, -1, playername, TRUE);
 			return TRUE;
 		}
 		break;
@@ -716,14 +705,13 @@ static gboolean mode_check_status(Player *player, gint event)
 }
 
 /* Returns a GList* to player 0 */
-GList *player_first_real(Game *game)
+GList *player_first_real(Game * game)
 {
 	GList *list;
 	/* search for player 0 */
 	playerlist_inc_use_count(game);
 	for (list = game->player_list;
-	     list != NULL; list = g_list_next(list))
-	{
+	     list != NULL; list = g_list_next(list)) {
 		Player *player = list->data;
 		if (player->num == 0)
 			break;
@@ -733,7 +721,7 @@ GList *player_first_real(Game *game)
 }
 
 /* Returns a GList * to a player with a number one higher than last */
-GList *player_next_real(GList *last)
+GList *player_next_real(GList * last)
 {
 	Player *player;
 	Game *game;
@@ -748,13 +736,13 @@ GList *player_next_real(GList *last)
 	game = player->game;
 	numplayers = game->params->num_players;
 	nextnum = player->num + 1;
-	
+
 	if (nextnum >= numplayers)
 		return NULL;
 
 	playerlist_inc_use_count(game);
 	for (list = game->player_list; list != NULL;
-			list = g_list_next (list) ) {
+	     list = g_list_next(list)) {
 		Player *scan = list->data;
 		if (scan->num == nextnum)
 			break;
@@ -763,7 +751,7 @@ GList *player_next_real(GList *last)
 	return list;
 }
 
-Player *player_by_name(Game *game, char *name)
+Player *player_by_name(Game * game, char *name)
 {
 	GList *list;
 
@@ -772,8 +760,9 @@ Player *player_by_name(Game *game, char *name)
 	     list != NULL; list = g_list_next(list)) {
 		Player *player = list->data;
 
-		if (player->name != NULL && strcmp(player->name, name) == 0) {
-		 	playerlist_dec_use_count(game);
+		if (player->name != NULL
+		    && strcmp(player->name, name) == 0) {
+			playerlist_dec_use_count(game);
 			return player;
 		}
 	}
@@ -782,7 +771,7 @@ Player *player_by_name(Game *game, char *name)
 	return NULL;
 }
 
-Player *player_by_num(Game *game, gint num)
+Player *player_by_num(Game * game, gint num)
 {
 	GList *list;
 
@@ -792,7 +781,7 @@ Player *player_by_num(Game *game, gint num)
 		Player *player = list->data;
 
 		if (player->num == num) {
-		 	playerlist_dec_use_count(game);
+			playerlist_dec_use_count(game);
 			return player;
 		}
 	}
@@ -801,13 +790,14 @@ Player *player_by_num(Game *game, gint num)
 	return NULL;
 }
 
-gboolean player_is_viewer(Game *game, gint player_num) {
+gboolean player_is_viewer(Game * game, gint player_num)
+{
 	return game->params->num_players <= player_num;
 }
 
 /* Returns a player that's not part of the game.
  */
-Player *player_none(Game *game)
+Player *player_none(Game * game)
 {
 	static Player player;
 
@@ -827,7 +817,8 @@ Player *player_none(Game *game)
  * +  = prepend 'player %d' to the message
  * -  = don't alter the message
  */
-void player_broadcast(Player *player, BroadcastType type, const char *fmt, ...)
+void player_broadcast(Player * player, BroadcastType type, const char *fmt,
+		      ...)
 {
 	Game *game = player->game;
 	char buff[4096];
@@ -840,61 +831,67 @@ void player_broadcast(Player *player, BroadcastType type, const char *fmt, ...)
 
 	playerlist_inc_use_count(game);
 	for (list = game->player_list; list != NULL;
-			list = g_list_next (list) ) {
+	     list = g_list_next(list)) {
 		Player *scan = list->data;
-		if (scan->disconnected || scan->num < 0) continue;
-		if (type == PB_SILENT || (scan == player && type == PB_RESPOND))
+		if (scan->disconnected || scan->num < 0)
+			continue;
+		if (type == PB_SILENT
+		    || (scan == player && type == PB_RESPOND))
 			sm_write(scan->sm, buff);
 		else if (scan != player || type == PB_ALL)
-			sm_send(scan->sm, "player %d %s", player->num, buff);
+			sm_send(scan->sm, "player %d %s", player->num,
+				buff);
 	}
 	playerlist_dec_use_count(game);
 }
 
-void player_set_name (Player *player, gchar *name)
+void player_set_name(Player * player, gchar * name)
 {
-	player_set_name_real (player, name, TRUE);
+	player_set_name_real(player, name, TRUE);
 }
 
-void player_remove(Player *player)
+void player_remove(Player * player)
 {
 	driver->player_removed(player);
 }
 
-GList *list_from_player (Player *player)
+GList *list_from_player(Player * player)
 {
 	GList *list;
-	for (list = player_first_real (player->game); list != NULL;
-			list = player_next_real (list) )
-		if (list->data == player) break;
-	g_assert (list != NULL);
+	for (list = player_first_real(player->game); list != NULL;
+	     list = player_next_real(list))
+		if (list->data == player)
+			break;
+	g_assert(list != NULL);
 	return list;
 }
 
-GList *next_player_loop (GList *current, Player *first)
+GList *next_player_loop(GList * current, Player * first)
 {
-	current = player_next_real (current);
-	if (current == NULL) current = player_first_real (first->game);
-	if (current->data == first) return NULL;
+	current = player_next_real(current);
+	if (current == NULL)
+		current = player_first_real(first->game);
+	if (current->data == first)
+		return NULL;
 	return current;
 }
 
-void playerlist_inc_use_count(Game *game)
+void playerlist_inc_use_count(Game * game)
 {
 	game->player_list_use_count++;
 }
 
-void playerlist_dec_use_count(Game *game)
+void playerlist_dec_use_count(Game * game)
 {
 	game->player_list_use_count--;
 	if (game->player_list_use_count == 0) {
 		GList *current;
 		GList *all_dead_players;
 		current = game->dead_players;
-		all_dead_players = game->dead_players; /* Remember this for g_list_free */
-		game->dead_players = NULL; /* Clear the list */
-		for (; current != NULL; current = g_list_next(current) ) {
-		 	Player *p = current->data;
+		all_dead_players = game->dead_players;	/* Remember this for g_list_free */
+		game->dead_players = NULL;	/* Clear the list */
+		for (; current != NULL; current = g_list_next(current)) {
+			Player *p = current->data;
 			player_free(p);
 		}
 		g_list_free(all_dead_players);
