@@ -20,28 +20,13 @@
  */
 
 #include "config.h"
-#include <fcntl.h>
-#include <ctype.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <netdb.h>
-#include <errno.h>
 #include <stdio.h>
 #include <string.h>
-
-#include <glib.h>
-
-#include "game.h"
-#include "cards.h"
-#include "map.h"
 #include "buildrec.h"
-#include "network.h"
-#include "cost.h"
 #include "server.h"
 
-static void build_add(Player *player, BuildType type, gint x, gint y, gint pos)
+static void build_add(Player * player, BuildType type, gint x, gint y,
+		      gint pos)
 {
 	StateMachine *sm = player->sm;
 	Game *game = player->game;
@@ -61,7 +46,8 @@ static void build_add(Player *player, BuildType type, gint x, gint y, gint pos)
 
 	if (type == BUILD_ROAD) {
 		/* Make sure that there are some roads left to use */
-		if (player->num_roads == game->params->num_build_type[BUILD_ROAD]) {
+		if (player->num_roads ==
+		    game->params->num_build_type[BUILD_ROAD]) {
 			sm_send(sm, "ERR too-many road\n");
 			return;
 		}
@@ -81,7 +67,8 @@ static void build_add(Player *player, BuildType type, gint x, gint y, gint pos)
 
 	if (type == BUILD_BRIDGE) {
 		/* Make sure that there are some bridges left to use */
-		if (player->num_bridges == game->params->num_build_type[BUILD_BRIDGE]) {
+		if (player->num_bridges ==
+		    game->params->num_build_type[BUILD_BRIDGE]) {
 			sm_send(sm, "ERR too-many bridge\n");
 			return;
 		}
@@ -101,7 +88,8 @@ static void build_add(Player *player, BuildType type, gint x, gint y, gint pos)
 
 	if (type == BUILD_SHIP) {
 		/* Make sure that there are some ships left to use */
-		if (player->num_ships == game->params->num_build_type[BUILD_SHIP]) {
+		if (player->num_ships ==
+		    game->params->num_build_type[BUILD_SHIP]) {
 			sm_send(sm, "ERR too-many ship\n");
 			return;
 		}
@@ -134,7 +122,7 @@ static void build_add(Player *player, BuildType type, gint x, gint y, gint pos)
 	node_add(player, BUILD_SETTLEMENT, x, y, pos, FALSE);
 }
 
-static void build_remove(Player *player)
+static void build_remove(Player * player)
 {
 	StateMachine *sm = player->sm;
 	/* Remove the settlement/road we just built
@@ -143,7 +131,7 @@ static void build_remove(Player *player)
 		sm_send(sm, "ERR bad-pos\n");
 }
 
-static void start_setup_player(Player *player)
+static void start_setup_player(Player * player)
 {
 	StateMachine *sm = player->sm;
 	Game *game = player->game;
@@ -155,10 +143,10 @@ static void start_setup_player(Player *player)
 	else
 		player_broadcast(player, PB_RESPOND, "setup\n");
 
-	sm_goto(sm, (StateFunc)mode_setup);
+	sm_goto(sm, (StateFunc) mode_setup);
 }
 
-static void allocate_resources(Player *player, BuildRec *rec)
+static void allocate_resources(Player * player, BuildRec * rec)
 {
 	Game *game = player->game;
 	Map *map = game->params->map;
@@ -178,12 +166,12 @@ static void allocate_resources(Player *player, BuildRec *rec)
 		}
 	}
 	/* give out the gold */
-	distribute_first (list_from_player (player) );
+	distribute_first(list_from_player(player));
 	return;
 }
 
 /* Player tried to finish setup mode */
-static void try_setup_done(Player *player)
+static void try_setup_done(Player * player)
 {
 	StateMachine *sm = player->sm;
 	Game *game = player->game;
@@ -196,7 +184,8 @@ static void try_setup_done(Player *player)
 	 * settlements/roads
 	 */
 	if (buildrec_count_edges(player->build_list) != num_allowed
-	    || buildrec_count_type(player->build_list, BUILD_SETTLEMENT) != num_allowed) {
+	    || buildrec_count_type(player->build_list,
+				   BUILD_SETTLEMENT) != num_allowed) {
 		sm_send(sm, "ERR expected-build-or-remove\n");
 		return;
 	}
@@ -213,36 +202,37 @@ static void try_setup_done(Player *player)
 	sm_send(sm, "OK\n");
 
 	if (game->double_setup)
-		allocate_resources(player, buildrec_get(player->build_list, BUILD_SETTLEMENT, 1));
+		allocate_resources(player,
+				   buildrec_get(player->build_list,
+						BUILD_SETTLEMENT, 1));
 	else if (game->reverse_setup)
-		allocate_resources(player, buildrec_get(player->build_list, BUILD_SETTLEMENT, 0));
+		allocate_resources(player,
+				   buildrec_get(player->build_list,
+						BUILD_SETTLEMENT, 0));
 	else {
-		sm_goto(sm, (StateFunc)mode_idle);
-		next_setup_player (game);
+		sm_goto(sm, (StateFunc) mode_idle);
+		next_setup_player(game);
 	}
 }
 
 /* find next player to do setup. */
-void next_setup_player (Game *game)
+void next_setup_player(Game * game)
 {
 	if (game->reverse_setup) {
 		/* Going back for second setup phase
 		 */
 		GList *prev = NULL, *list;
-		for (list = player_first_real (game); list != NULL;
-				list = player_next_real (list) ) {
-			if (list == game->setup_player) break;
+		for (list = player_first_real(game); list != NULL;
+		     list = player_next_real(list)) {
+			if (list == game->setup_player)
+				break;
 			prev = list;
 		}
 		game->setup_player = prev;
 		game->double_setup = FALSE;
-		if (game->setup_player_name)
-			g_free(game->setup_player_name);
 		if (game->setup_player != NULL) {
 			start_setup_player(game->setup_player->data);
-			game->setup_player_name = g_strdup(((Player *)game->setup_player->data)->name);
-		}
-		else {
+		} else {
 			/* Start the game!!!
 			 */
 			turn_next_player(game);
@@ -251,15 +241,12 @@ void next_setup_player (Game *game)
 		/* First setup phase
 		 */
 		Player *player;
-		game->setup_player = player_next_real (game->setup_player);
+		game->setup_player = player_next_real(game->setup_player);
 		player = game->setup_player->data;
-		if (game->setup_player_name)
-			g_free(game->setup_player_name);
-		game->setup_player_name = g_strdup(player->name);
 		/* Last player gets double setup
 		 */
 		game->double_setup
-			= player_next_real (game->setup_player) == NULL;
+		    = player_next_real(game->setup_player) == NULL;
 		/* Prepare to go backwards next time
 		 */
 		game->reverse_setup = game->double_setup;
@@ -270,13 +257,13 @@ void next_setup_player (Game *game)
 /* Player must place exactly one settlement and one road which connect
  * to each other.  If last player, then perform a double setup.
  */
-gboolean mode_setup(Player *player, gint event)
+gboolean mode_setup(Player * player, gint event)
 {
 	StateMachine *sm = player->sm;
 	BuildType type;
 	gint x, y, pos;
 
-        sm_state_name(sm, "mode_setup");
+	sm_state_name(sm, "mode_setup");
 	if (event != SM_RECV)
 		return FALSE;
 
@@ -296,7 +283,7 @@ gboolean mode_setup(Player *player, gint event)
 	return FALSE;
 }
 
-static void try_start_game(Game *game)
+static void try_start_game(Game * game)
 {
 	GList *list;
 	int num;
@@ -308,21 +295,19 @@ static void try_start_game(Game *game)
 	     list != NULL; list = player_next_real(list)) {
 		Player *player = list->data;
 
-		if (sm_current(player->sm) == (StateFunc)mode_idle)
+		if (sm_current(player->sm) == (StateFunc) mode_idle)
 			num++;
 
-		if (sm_current(player->sm) == (StateFunc)mode_turn ||
+		if (sm_current(player->sm) == (StateFunc) mode_turn ||
 		    sm_current(player->sm)
-                     == (StateFunc)mode_discard_resources ||
+		    == (StateFunc) mode_discard_resources ||
 		    sm_current(player->sm)
-                     == (StateFunc)mode_place_robber ||
+		    == (StateFunc) mode_place_robber ||
 		    sm_current(player->sm)
-                     == (StateFunc)mode_road_building ||
+		    == (StateFunc) mode_road_building ||
 		    sm_current(player->sm)
-                     == (StateFunc)mode_monopoly ||
-		    sm_current(player->sm)
-                     == (StateFunc)mode_plenty_resources)
-		{
+		    == (StateFunc) mode_monopoly || sm_current(player->sm)
+		    == (StateFunc) mode_plenty_resources) {
 			/* looks like this player got disconnected and
 			   now it's his turn. */
 			num++;
@@ -332,8 +317,7 @@ static void try_start_game(Game *game)
 	if (num != game->params->num_players)
 		return;
 
-	if (numturn > 0)
-	{
+	if (numturn > 0) {
 		/* someone got disconnected. Now everyone's back. Let's
 		   continue the game... */
 
@@ -343,12 +327,9 @@ static void try_start_game(Game *game)
 	/* All players have connected, and are ready to begin
 	 */
 	meta_start_game();
-	game->setup_player = game->player_list;
-	while (((Player *)game->setup_player->data)->num < 0)
+	game->setup_player = player_first_real(game);
+	while (((Player *) game->setup_player->data)->num < 0)
 		game->setup_player = game->setup_player->next;
-	if (game->setup_player_name)
-		g_free(game->setup_player_name);
-	game->setup_player_name = g_strdup(((Player *)game->setup_player->data)->name);
 	game->double_setup = game->reverse_setup = FALSE;
 
 	start_setup_player(game->setup_player->data);
@@ -356,7 +337,7 @@ static void try_start_game(Game *game)
 
 /* Send the player list to the client
  */
-static void send_player_list(Player *player)
+static void send_player_list(Player * player)
 {
 	StateMachine *sm = player->sm;
 	Game *game = player->game;
@@ -364,9 +345,10 @@ static void send_player_list(Player *player)
 
 	sm_send(sm, "players follow\n");
 	for (list = game->player_list; list != NULL;
-			list = g_list_next (list) ) {
+	     list = g_list_next(list)) {
 		Player *scan = list->data;
-		if (player == scan || scan->num < 0) continue;
+		if (player == scan || scan->num < 0)
+			continue;
 		sm_send(sm, "player %d is %s\n", scan->num, scan->name);
 	}
 	sm_send(sm, ".\n");
@@ -374,33 +356,29 @@ static void send_player_list(Player *player)
 
 /* Send the game parameters to the player
  */
-static void send_game_line(Player *player, gchar *str)
+static void send_game_line(Player * player, gchar * str)
 {
 	StateMachine *sm = player->sm;
 	sm_send(sm, "%s\n", str);
 }
 
-gboolean send_gameinfo(Map *map, Hex *hex, Player *player)
+gboolean send_gameinfo(Map * map, Hex * hex, Player * player)
 {
 	StateMachine *sm = player->sm;
 	gint i;
-	for (i = 0; i < numElem (hex->nodes); i++)
-	{
-		if (!hex->nodes[i] || hex->nodes[i]->x != hex->x || hex->nodes[i]->y != hex->y)
+	for (i = 0; i < numElem(hex->nodes); i++) {
+		if (!hex->nodes[i] || hex->nodes[i]->x != hex->x
+		    || hex->nodes[i]->y != hex->y)
 			continue;
-		if (hex->nodes[i]->owner >= 0)
-		{
-			switch (hex->nodes[i]->type)
-			{
+		if (hex->nodes[i]->owner >= 0) {
+			switch (hex->nodes[i]->type) {
 			case BUILD_SETTLEMENT:
 				sm_send(sm, "S%d,%d,%d,%d\n", hex->x,
-					hex->y, i,
-					hex->nodes[i]->owner);
+					hex->y, i, hex->nodes[i]->owner);
 				break;
 			case BUILD_CITY:
 				sm_send(sm, "C%d,%d,%d,%d\n", hex->x,
-					hex->y, i,
-					hex->nodes[i]->owner);
+					hex->y, i, hex->nodes[i]->owner);
 				break;
 			default:
 				;
@@ -408,28 +386,23 @@ gboolean send_gameinfo(Map *map, Hex *hex, Player *player)
 		}
 	}
 
-	for (i = 0; i < numElem (hex->edges); i++)
-	{
-		if (!hex->edges[i] || hex->edges[i]->x != hex->x || hex->edges[i]->y != hex->y)
+	for (i = 0; i < numElem(hex->edges); i++) {
+		if (!hex->edges[i] || hex->edges[i]->x != hex->x
+		    || hex->edges[i]->y != hex->y)
 			continue;
-		if (hex->edges[i]->owner >= 0)
-		{
-			switch (hex->edges[i]->type)
-			{
+		if (hex->edges[i]->owner >= 0) {
+			switch (hex->edges[i]->type) {
 			case BUILD_ROAD:
 				sm_send(sm, "R%d,%d,%d,%d\n", hex->x,
-					hex->y, i,
-					hex->edges[i]->owner);
+					hex->y, i, hex->edges[i]->owner);
 				break;
 			case BUILD_SHIP:
 				sm_send(sm, "SH%d,%d,%d,%d\n", hex->x,
-					hex->y, i,
-					hex->edges[i]->owner);
+					hex->y, i, hex->edges[i]->owner);
 				break;
 			case BUILD_BRIDGE:
 				sm_send(sm, "B%d,%d,%d,%d\n", hex->x,
-					hex->y, i,
-					hex->edges[i]->owner);
+					hex->y, i, hex->edges[i]->owner);
 				break;
 			default:
 				;
@@ -437,13 +410,11 @@ gboolean send_gameinfo(Map *map, Hex *hex, Player *player)
 		}
 	}
 
-	if (hex->robber)
-	{
+	if (hex->robber) {
 		sm_send(sm, "RO%d,%d\n", hex->x, hex->y);
 	}
 
-	if (hex == map->pirate_hex)
-	{
+	if (hex == map->pirate_hex) {
 		sm_send(sm, "P%d,%d\n", hex->x, hex->y);
 	}
 
@@ -452,10 +423,10 @@ gboolean send_gameinfo(Map *map, Hex *hex, Player *player)
 
 /* Player setup phase
  */
-gboolean mode_pre_game(Player *player, gint event)
+gboolean mode_pre_game(Player * player, gint event)
 {
 	/* When entering this state: disconnect this player, and reconnect at the end */
-	static gboolean old_player_disconnected; 
+	static gboolean old_player_disconnected;
 	StateMachine *sm = player->sm;
 	Game *game = player->game;
 	Map *map = game->params->map;
@@ -466,6 +437,7 @@ gboolean mode_pre_game(Player *player, gint event)
 	gint longestroadpnum = -1;
 	gint largestarmypnum = -1;
 	static gboolean recover_from_plenty = FALSE;
+	guint stack_offset;
 
 	if (game->longest_road) {
 		longestroadpnum = game->longest_road->num;
@@ -474,10 +446,11 @@ gboolean mode_pre_game(Player *player, gint event)
 		largestarmypnum = game->largest_army->num;
 	}
 
-        sm_state_name(sm, "mode_pre_game");
+	sm_state_name(sm, "mode_pre_game");
 	switch (event) {
 	case SM_ENTER:
-		sm_send(sm, "player %d of %d, welcome to gnocatan server %s\n",
+		sm_send(sm,
+			"player %d of %d, welcome to gnocatan server %s\n",
 			player->num, game->params->num_players, VERSION);
 		/* Tell the player that he exists.  This is not done in
 		 * player_set_name, because at that point the client doesn't
@@ -488,7 +461,8 @@ gboolean mode_pre_game(Player *player, gint event)
 		/* Tell the other players about this player */
 		player_broadcast(player, PB_ALL, "is %s\n", player->name);
 		/* Tell this player his own name */
-		sm_send(sm, "player %d is %s\n", player->num, player->name);
+		sm_send(sm, "player %d is %s\n", player->num,
+			player->name);
 		break;
 
 	case SM_RECV:
@@ -497,116 +471,91 @@ gboolean mode_pre_game(Player *player, gint event)
 			return TRUE;
 		}
 		if (sm_recv(sm, "game")) {
-			params_write_lines(game->params, (WriteLineFunc)send_game_line, player);
+			params_write_lines(game->params,
+					   (WriteLineFunc) send_game_line,
+					   player);
 			return TRUE;
 		}
 		if (sm_recv(sm, "gameinfo")) {
 			sm_send(sm, "gameinfo\n");
-			map_traverse(map, (HexFunc)send_gameinfo, player);
+			map_traverse(map, (HexFunc) send_gameinfo, player);
 			sm_send(sm, ".\n");
 
 			/* now, send state info */
 			sm_send(sm, "turn num %d\n", game->curr_turn);
-			if (game->curr_player >=0)
-			{
+			if (game->curr_player >= 0) {
 				Player *playerturn
-				 = player_by_num(game, game->curr_player);
+				    =
+				    player_by_num(game, game->curr_player);
 				sm_send(sm, "player turn: %d\n",
-				        playerturn->num);
+					playerturn->num);
 			}
-			if (game->rolled_dice)
-			{
+			if (game->rolled_dice) {
 				sm_send(sm, "dice rolled: %d %d\n",
-				        game->die1, game->die2);
-			}
-			else if (game->die1 + game->die2 > 1)
-			{
+					game->die1, game->die2);
+			} else if (game->die1 + game->die2 > 1) {
 				sm_send(sm, "dice value: %d %d\n",
-				        game->die1, game->die2);
+					game->die1, game->die2);
 			}
-			if (game->played_develop)
-			{
+			if (game->played_develop) {
 				sm_send(sm, "played develop\n");
 			}
-			if (game->bought_develop)
-			{
+			if (game->bought_develop) {
 				sm_send(sm, "bought develop\n");
 			}
-			if (old_player_disconnected)
-			{
+			if (old_player_disconnected) {
 				sm_send(sm, "player disconnected\n");
 			}
-			state = old_player_disconnected
-			      ? sm_previous(player->sm)
-			      : sm_current(player->sm);
-			if (state == (StateFunc)mode_idle)
-				strcpy(prevstate, "IDLE");
-			else if (state == (StateFunc)mode_turn) {
-				strcpy(prevstate, "TURN");
-				if (game->rolled_dice && game->die1 + game->die2 == 7) {
-					/* search for the player who is the robber */
-					for (next = game->player_list;
-					     next != NULL; next = g_list_next(next)) {
-						Player *p = (Player *)next->data;
-						state = p->disconnected
-						      ? sm_previous(p->sm) : sm_current(p->sm);
-						if (state == (StateFunc)mode_place_robber) {
-							sprintf(prevstate, "ISROBBER %d", p->num);
-							break;
-						}
-					}
-				}
+			stack_offset = 1;
+			state = sm_stack_inspect(player->sm, stack_offset);
+			while ((state == (StateFunc) mode_choose_gold) ||
+			       (state == (StateFunc)
+				mode_wait_for_gold_choosing_players)) {
+				++stack_offset;
+				state =
+				    sm_stack_inspect(player->sm,
+						     stack_offset);
 			}
-			else if (state == (StateFunc)mode_discard_resources)
-				strcpy(prevstate, "DISCARD");
-			else if (state == (StateFunc)mode_wait_for_other_discarding_players)
-				strcpy(prevstate, "DISCARD");
-			else if (state == (StateFunc)mode_place_robber)
-				strcpy(prevstate, "YOUAREROBBER");
-			else if (state == (StateFunc)mode_road_building)
-				strcpy(prevstate, "ROADBUILDING");
-			else if (state == (StateFunc)mode_monopoly)
-				strcpy(prevstate, "MONOPOLY");
-			else if (state == (StateFunc)mode_plenty_resources) {
-				recover_from_plenty = TRUE;
-				sprintf(prevstate, "PLENTY");
-			} else if (state == (StateFunc)mode_choose_gold)
-				sprintf(prevstate, "GOLD");
-			else if (state == (StateFunc)mode_setup) {
-				/* reconstruct the setup_player list */
-				/* search for the player whose setup it
-				   is */
-				for (next = game->player_list;
-				     next != NULL; next = g_list_next(next)) {
-					if (strcmp(((Player *)next->data)->name, game->setup_player_name) == 0) {
-						game->setup_player = next;
-						break;
-					}
-				}
 
-				if (game->double_setup) {
-					sprintf(prevstate, "SETUPDOUBLE");
-				}
-				else {
-					sprintf(prevstate, "SETUP");
-				}
-			}
-			else
+			if (state == (StateFunc) mode_idle)
+				strcpy(prevstate, "IDLE");
+			else if (state == (StateFunc) mode_turn)
+				strcpy(prevstate, "TURN");
+			else if (state ==
+				 (StateFunc) mode_discard_resources)
+				strcpy(prevstate, "DISCARD");
+			else if (state == (StateFunc)
+				 mode_wait_for_other_discarding_players)
+				strcpy(prevstate, "DISCARD");
+			else if (state == (StateFunc) mode_place_robber)
+				strcpy(prevstate, "YOUAREROBBER");
+			else if (state == (StateFunc) mode_road_building)
+				strcpy(prevstate, "ROADBUILDING");
+			else if (state == (StateFunc) mode_monopoly)
+				strcpy(prevstate, "MONOPOLY");
+			else if (state ==
+				 (StateFunc) mode_plenty_resources) {
+				recover_from_plenty = TRUE;
+				strcpy(prevstate, "PLENTY");
+			} else if (state == (StateFunc) mode_setup) {
+				if (game->double_setup)
+					strcpy(prevstate, "SETUPDOUBLE");
+				else
+					strcpy(prevstate, "SETUP");
+				/* If player is selecting gold, the state 
+				 * should be IDLE instead */
+				if (stack_offset != 1)
+					strcpy(prevstate, "IDLE");
+			} else
 				strcpy(prevstate, "PREGAME");
 
-			/* Special processing of extra arguments */
-			if (state == (StateFunc)mode_choose_gold) {
-				sm_send(sm, "state GOLD %d %R\n", player->gold, game->bank_deck);
-			}
-			else
-			{
-				sm_send(sm, "state %s\n", prevstate);
-			}
-			
+			sm_send(sm, "state %s\n", prevstate);
+
 			/* Send the bank, so the client can count remaining 
 			 * resources
 			 */
-			sm_send(sm, "extension bank %R\n", game->bank_deck);
+			sm_send(sm, "extension bank %R\n",
+				game->bank_deck);
 
 			/* send player info about what he has:
 			   resources, dev cards, roads, # roads,
@@ -615,51 +564,68 @@ gboolean mode_pre_game(Player *player, gint event)
 			   who has longest road/army */
 			/* Only send this when the player is not a viewer */
 			if (!player_is_viewer(game, player->num)) {
-				sm_send(sm, "playerinfo: resources: %R\n", player->assets);
-				sm_send(sm, "playerinfo: numdevcards: %d\n", player->devel->num_cards);
-				for (i = 0; i < player->devel->num_cards; i++)
-				{
-					sm_send(sm, "playerinfo: devcard: %d %d\n", (gint)player->devel->cards[i].type, player->devel->cards[i].turn_bought);
+				sm_send(sm, "playerinfo: resources: %R\n",
+					player->assets);
+				sm_send(sm,
+					"playerinfo: numdevcards: %d\n",
+					player->devel->num_cards);
+				for (i = 0; i < player->devel->num_cards;
+				     i++) {
+					sm_send(sm,
+						"playerinfo: devcard: %d %d\n",
+						(gint) player->devel->
+						cards[i].type,
+						player->devel->cards[i].
+						turn_bought);
 				}
-				sm_send(sm, "playerinfo: %d %d %d %d %d %d %d %d %d %d %d %d %d %d\n",
-					player->num_roads, player->num_bridges,
-					player->num_ships, player->num_settlements,
-					player->num_cities, player->num_soldiers,
-					player->road_len, player->chapel_played,
-					player->univ_played, player->gov_played,
-					player->libr_played, player->market_played,
+				sm_send(sm,
+					"playerinfo: %d %d %d %d %d %d %d %d %d %d %d %d %d %d\n",
+					player->num_roads,
+					player->num_bridges,
+					player->num_ships,
+					player->num_settlements,
+					player->num_cities,
+					player->num_soldiers,
+					player->road_len,
+					player->chapel_played,
+					player->univ_played,
+					player->gov_played,
+					player->libr_played,
+					player->market_played,
 					(player->num == longestroadpnum),
 					(player->num == largestarmypnum));
 			}
 			/* send info about other players */
-			for (next = player_first_real (game); next != NULL;
-					next = player_next_real (next))
-			{
-				Player *p = (Player *)next->data;
+			for (next = player_first_real(game); next != NULL;
+			     next = player_next_real(next)) {
+				Player *p = (Player *) next->data;
 				gint numassets = 0;
 				if (p->num == player->num)
 					continue;
 				for (i = 0; i < NO_RESOURCE; i++) {
 					numassets += p->assets[i];
 				}
-				sm_send(sm, "otherplayerinfo: %d %d %d %d %d %d %d %d %d %d %d\n",
-				        p->num, numassets, p->devel->num_cards,
-				        p->num_soldiers, p->chapel_played,
+				sm_send(sm,
+					"otherplayerinfo: %d %d %d %d %d %d %d %d %d %d %d\n",
+					p->num, numassets,
+					p->devel->num_cards,
+					p->num_soldiers, p->chapel_played,
 					p->univ_played, p->gov_played,
 					p->libr_played, p->market_played,
-				        (p->num == longestroadpnum),
-				        (p->num == largestarmypnum));
+					(p->num == longestroadpnum),
+					(p->num == largestarmypnum));
 			}
 
 			/* send build info for the current player
 			   - what builds the player was in the process
-			     of building when he disconnected */
+			   of building when he disconnected */
 			for (next = player->build_list;
-			     next != NULL; next = g_list_next(next))
-			{
-				BuildRec *build = (BuildRec *)next->data;
+			     next != NULL; next = g_list_next(next)) {
+				BuildRec *build = (BuildRec *) next->data;
 				sm_send(sm, "buildinfo: %B %d %d %d %d\n",
-					build->type, BUILD_NONE, build->x, build->y, build->pos); /** @todo RC 2004-03-28 Remove BUILD_NONE for 0.9 */
+					build->type, BUILD_NONE, build->x,
+					build->y, build->pos);
+												  /** @todo RC 2004-03-28 Remove BUILD_NONE for 0.9 */
 			}
 
 			sm_send(sm, "end\n");
@@ -667,36 +633,57 @@ gboolean mode_pre_game(Player *player, gint event)
 		}
 		if (sm_recv(sm, "start")) {
 			sm_send(sm, "OK\n");
-			
+
+			/* Some player was in the setup phase */
+			if (game->setup_player != NULL)
+				sm_send(sm, "player %d setup\n",
+					((Player *) (game->setup_player->
+						     data))->num);
+
 			if (recover_from_plenty) {
-				sm_send(sm, "plenty %R\n", game->bank_deck);
+				sm_send(sm, "plenty %R\n",
+					game->bank_deck);
 				recover_from_plenty = FALSE;
 			}
 
-			/* send discard info for all players */
-			for (next = player_first_real (game); next != NULL;
-					next = player_next_real (next))
-			{
-				Player *p = (Player *)next->data;
+			/* send discard and gold info for all players */
+			for (next = player_first_real(game); next != NULL;
+			     next = player_next_real(next)) {
+				Player *p = (Player *) next->data;
 				if (p->discard_num > 0) {
-					sm_send(sm, "player %d must-discard %d\n",
-					        p->num, p->discard_num);
+					sm_send(sm,
+						"player %d must-discard %d\n",
+						p->num, p->discard_num);
+				}
+				if (p->gold > 0) {
+					sm_send(sm,
+						"player %d prepare-gold %d\n",
+						p->num, p->gold);
+
 				}
 			}
 
+			/* The current player was choosing gold */
+			state = sm_stack_inspect(player->sm, 1);
+			if (state == (StateFunc) mode_choose_gold) {
+				gint limited_bank[NO_RESOURCE];
+				gold_limited_bank(game, player->gold,
+						  limited_bank);
+				sm_send(sm, "choose-gold %d %R\n",
+					player->gold, limited_bank);
+			}
+
 			player->disconnected = old_player_disconnected;
-			if (player->disconnected)
-			{
+			if (player->disconnected) {
 				player->disconnected = FALSE;
 				driver->player_change(game);
 				sm_pop(sm);
-			}
-			else
-			{
+			} else {
 				if (!player_is_viewer(game, player->num))
-					sm_goto(sm, (StateFunc)mode_idle);
+					sm_goto(sm, (StateFunc) mode_idle);
 				else
-					sm_goto (sm, (StateFunc)mode_viewer);
+					sm_goto(sm,
+						(StateFunc) mode_viewer);
 			}
 			try_start_game(game);
 			return TRUE;
