@@ -20,27 +20,12 @@
  */
 
 #include "config.h"
-#include <fcntl.h>
-#include <ctype.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <netdb.h>
-#include <errno.h>
 #include <string.h>
-
-#include <glib.h>
-
-#include "game.h"
-#include "cards.h"
-#include "map.h"
-#include "buildrec.h"
-#include "network.h"
 #include "cost.h"
 #include "server.h"
 
-gboolean resource_available(Player *player, gint *resources, gint *num_in_bank)
+gboolean resource_available(Player * player, gint * resources,
+			    gint * num_in_bank)
 {
 	StateMachine *sm = player->sm;
 	Game *game = player->game;
@@ -60,7 +45,7 @@ gboolean resource_available(Player *player, gint *resources, gint *num_in_bank)
 	return TRUE;
 }
 
-void resource_start(Game *game)
+void resource_start(Game * game)
 {
 	GList *list;
 
@@ -74,7 +59,7 @@ void resource_start(Game *game)
 	}
 }
 
-void resource_end(Game *game, const gchar *action, gint mult)
+void resource_end(Game * game, const gchar * action, gint mult)
 {
 	GList *list;
 
@@ -88,11 +73,12 @@ void resource_end(Game *game, const gchar *action, gint mult)
 		for (idx = 0; idx < numElem(player->assets); idx++) {
 			gint num;
 
-			num = player->assets[idx] - player->prev_assets[idx];
+			num =
+			    player->assets[idx] - player->prev_assets[idx];
 			if (game->bank_deck[idx] - num < 0) {
 				num = game->bank_deck[idx];
 				player->assets[idx]
-					= player->prev_assets[idx] + num;
+				    = player->prev_assets[idx] + num;
 			}
 
 			resource[idx] = num;
@@ -105,12 +91,13 @@ void resource_end(Game *game, const gchar *action, gint mult)
 		if (send_message) {
 			for (idx = 0; idx < NO_RESOURCE; idx++)
 				resource[idx] *= mult;
-			player_broadcast(player, PB_ALL, "%s %R\n", action, resource);
+			player_broadcast(player, PB_ALL, "%s %R\n", action,
+					 resource);
 		}
 	}
 }
 
-void resource_spend(Player *player, gint *cost)
+void resource_spend(Player * player, gint * cost)
 {
 	Game *game = player->game;
 
@@ -119,7 +106,7 @@ void resource_spend(Player *player, gint *cost)
 	resource_end(game, "spent", -1);
 }
 
-void resource_refund(Player *player, gint *cost)
+void resource_refund(Player * player, gint * cost)
 {
 	Game *game = player->game;
 
