@@ -39,8 +39,8 @@ typedef struct {
 	gchar *client_version;
 
 	GList *build_list;	/* list of building that can be undone */
-	gint prev_assets[NO_RESOURCE]; /* remember previous resources */
-	gint assets[NO_RESOURCE]; /* our resources */
+	gint prev_assets[NO_RESOURCE];	/* remember previous resources */
+	gint assets[NO_RESOURCE];	/* our resources */
 	gint gold;		/* how much gold will we recieve? */
 	DevelDeck *devel;	/* development cards we own */
 	GList *points;		/* points from special actions */
@@ -65,6 +65,7 @@ typedef struct {
 
 struct Game {
 	GameParams *params;	/* game parameters */
+	gchar *hostname;	/* reported hostname */
 
 	int accept_fd;		/* socket for accepting new clients */
 	int accept_tag;		/* Gdk event tag for accept socket */
@@ -77,7 +78,6 @@ struct Game {
 	gboolean double_setup;
 	gboolean reverse_setup;
 	GList *setup_player;
-	gchar *setup_player_name;
 
 	gboolean is_game_over;	/* is the game over? */
 	Player *longest_road;	/* who holds longest road */
@@ -89,44 +89,48 @@ struct Game {
 	gint curr_turn;		/* current turn number */
 	gboolean rolled_dice;	/* has dice been rolled in turn yet? */
 	gint die1, die2;	/* latest dice values */
-	gboolean played_develop; /* has devel. card been played in turn? */
-	gboolean bought_develop; /* has devel. card been bought in turn? */
+	gboolean played_develop;	/* has devel. card been played in turn? */
+	gboolean bought_develop;	/* has devel. card been bought in turn? */
 
-	gint bank_deck[NO_RESOURCE]; /* resource card bank */
+	gint bank_deck[NO_RESOURCE];	/* resource card bank */
 	gint num_develop;	/* number of development cards */
 	gint *develop_deck;	/* development cards */
 	gint develop_next;	/* next development card to deal */
+
+	gboolean register_server;	/* register game with meta-server? */
+	gchar *server_port;	/* port to run game on */
+	gboolean random_order;	/* is turn order randomized? */
 };
 
 /* buildutil.c */
-void check_longest_road (Game *game, gboolean can_cut);
-void node_add(Player *player,
+void check_longest_road(Game * game, gboolean can_cut);
+void node_add(Player * player,
 	      BuildType type, int x, int y, int pos, gboolean paid_for);
-void edge_add(Player *player,
+void edge_add(Player * player,
 	      BuildType type, int x, int y, int pos, gboolean paid_for);
-gboolean perform_undo(Player *player);
+gboolean perform_undo(Player * player);
 
 /* develop.c */
-void develop_shuffle(Game *game);
-void develop_buy(Player *player);
-void develop_play(Player *player, gint idx);
-gboolean mode_road_building(Player *player, gint event);
-gboolean mode_plenty_resources(Player *player, gint event);
-gboolean mode_monopoly(Player *player, gint event);
+void develop_shuffle(Game * game);
+void develop_buy(Player * player);
+void develop_play(Player * player, gint idx);
+gboolean mode_road_building(Player * player, gint event);
+gboolean mode_plenty_resources(Player * player, gint event);
+gboolean mode_monopoly(Player * player, gint event);
 
 /* discard.c */
-void discard_resources(Game *player);
-gboolean mode_discard_resources(Player *player, gint event);
-gboolean mode_wait_others_place_robber(Player *player, gint event);
-gboolean mode_discard_resources_place_robber(Player *player, gint event);
+void discard_resources(Game * player);
+gboolean mode_discard_resources(Player * player, gint event);
+gboolean mode_wait_others_place_robber(Player * player, gint event);
+gboolean mode_discard_resources_place_robber(Player * player, gint event);
 
 /* meta.c */
 extern const gchar *meta_server_name;
-extern gchar *hostname;
-void meta_register(const gchar *server, const gchar *port, Game *game);
+gchar *get_server_name(void);
+void meta_register(const gchar * server, const gchar * port, Game * game);
 void meta_start_game(void);
 void meta_report_num_players(gint num_players);
-void meta_send_details(Game *game);
+void meta_send_details(Game * game);
 
 /* player.c */
 typedef enum {
@@ -135,83 +139,91 @@ typedef enum {
 	PB_SILENT,
 	PB_OTHERS
 } BroadcastType;
-Player *player_new(Game *game, int fd, gchar *location);
-void player_setup(Player *player, int playernum, gchar *name, gboolean
-		force_viewer);
-Player *player_by_name(Game *game, char *name);
-Player *player_by_num(Game *game, gint num);
-void player_set_name(Player *player, gchar *name);
-Player *player_none(Game *game);
-void player_broadcast(Player *player, BroadcastType type, const char *fmt, ...);
-void player_remove(Player *player);
-void player_free(Player *player);
-void player_archive(Player *player);
-void player_revive(Player *newp, char *name);
-GList *player_first_real(Game *game);
-GList *player_next_real(GList *last);
-GList *list_from_player (Player *player);
-GList *next_player_loop (GList *current, Player *first);
-gboolean mode_viewer (Player *player, gint event);
-void playerlist_inc_use_count(Game *game);
-void playerlist_dec_use_count(Game *game);
-gboolean player_is_viewer(Game *game, gint player_num);
+Player *player_new(Game * game, int fd, gchar * location);
+void player_setup(Player * player, int playernum, gchar * name, gboolean
+		  force_viewer);
+Player *player_by_name(Game * game, char *name);
+Player *player_by_num(Game * game, gint num);
+void player_set_name(Player * player, gchar * name);
+Player *player_none(Game * game);
+void player_broadcast(Player * player, BroadcastType type, const char *fmt,
+		      ...);
+void player_remove(Player * player);
+void player_free(Player * player);
+void player_archive(Player * player);
+void player_revive(Player * newp, char *name);
+GList *player_first_real(Game * game);
+GList *player_next_real(GList * last);
+GList *list_from_player(Player * player);
+GList *next_player_loop(GList * current, Player * first);
+gboolean mode_viewer(Player * player, gint event);
+void playerlist_inc_use_count(Game * game);
+void playerlist_dec_use_count(Game * game);
+gboolean player_is_viewer(Game * game, gint player_num);
 
 /* pregame.c */
-gboolean mode_pre_game(Player *player, gint event);
-gboolean mode_setup(Player *player, gint event);
-gboolean send_gameinfo(Map *map, Hex *hex, Player *sm);
-void next_setup_player (Game *game);
+gboolean mode_pre_game(Player * player, gint event);
+gboolean mode_setup(Player * player, gint event);
+gboolean send_gameinfo(Map * map, Hex * hex, Player * sm);
+void next_setup_player(Game * game);
 
 /* resource.c */
-gboolean resource_available(Player *player,
-			    gint *resources, gint *num_in_bank);
-void resource_maritime_trade(Player *player,
-			     Resource supply, Resource receive, gint ratio);
-void resource_start(Game *game);
-void resource_end(Game *game, const gchar *action, gint mult);
-void resource_spend(Player *player, gint *cost);
-void resource_refund(Player *player, gint *cost);
+gboolean resource_available(Player * player,
+			    gint * resources, gint * num_in_bank);
+void resource_maritime_trade(Player * player,
+			     Resource supply, Resource receive,
+			     gint ratio);
+void resource_start(Game * game);
+void resource_end(Game * game, const gchar * action, gint mult);
+void resource_spend(Player * player, gint * cost);
+void resource_refund(Player * player, gint * cost);
 
 /* robber.c */
-void robber_place(Player *player);
-gboolean mode_place_robber(Player *player, gint event);
+void robber_place(Player * player);
+gboolean mode_place_robber(Player * player, gint event);
 
 /* server.c */
 void timed_out(int signum);
 void start_timeout(void);
 void stop_timeout(void);
 gint get_rand(gint range);
-Game *game_new(GameParams *params);
-void game_free(Game *game);
-gint new_computer_player(const gchar *server, const gchar *port);
-gboolean server_startup(GameParams *params, const gchar *port, gboolean meta);
+Game *game_new(GameParams * params);
+void game_free(Game * game);
+gint new_computer_player(const gchar * server, const gchar * port);
+gboolean server_startup(GameParams * params, const gchar * hostname,
+			const gchar * port, gboolean meta,
+			gboolean random_order);
 gboolean server_stop(void);
 gboolean server_is_running(void);
-gint accept_connection(gint in_fd, gchar **location);
-gint open_listen_socket(gchar *port);
+gint accept_connection(gint in_fd, gchar ** location);
+gint open_listen_socket(gchar * port);
 
 /* trade.c */
-void trade_perform_maritime(Player *player,
+void trade_perform_maritime(Player * player,
 			    gint ratio, Resource supply, Resource receive);
-gboolean mode_wait_quote_exit(Player *player, gint event);
-gboolean mode_domestic_quote(Player *player, gint event);
-void trade_finish_domestic(Player *player);
-void trade_accept_domestic(Player *player,
+gboolean mode_wait_quote_exit(Player * player, gint event);
+gboolean mode_domestic_quote(Player * player, gint event);
+void trade_finish_domestic(Player * player);
+void trade_accept_domestic(Player * player,
 			   gint partner_num, gint quote_num,
-			   gint *supply, gint *receive);
-gboolean mode_domestic_initiate(Player *player, gint event);
-void trade_begin_domestic(Player *player, gint *supply, gint *receive);
+			   gint * supply, gint * receive);
+gboolean mode_domestic_initiate(Player * player, gint event);
+void trade_begin_domestic(Player * player, gint * supply, gint * receive);
 
 /* turn.c */
-gboolean mode_idle(Player *player, gint event);
-gboolean mode_turn(Player *player, gint event);
-void turn_next_player(Game *game);
-void check_victory(Player *player);
+gboolean mode_idle(Player * player, gint event);
+gboolean mode_turn(Player * player, gint event);
+void turn_next_player(Game * game);
+void check_victory(Player * player);
 
 /* gold.c */
-void distribute_first (GList *list);
-gboolean mode_choose_gold(Player *player, gint event);
+gboolean gold_limited_bank(const Game * game, int limit,
+			   gint * limited_bank);
+void distribute_first(GList * list);
+gboolean mode_choose_gold(Player * player, gint event);
+gboolean mode_wait_for_gold_choosing_players(Player * player, gint event);
 
 /* discard.c */
-gboolean mode_wait_for_other_discarding_players(Player *player, gint event);
+gboolean mode_wait_for_other_discarding_players(Player * player,
+						gint event);
 #endif
